var fireEvent;
(function(jQuery){
	 "use strict";
    jQuery(document).ready(function(){		//when DOM is ready
        theme.init();
    });
    jQuery(window).resize(function() {
        clearTimeout(fireEvent);
        fireEvent = setTimeout(theme.resizeEvent, 200);
	});
})(jQuery);
jQuery(window).load(function() {
    theme.initGoogleMaps();
});

var theme = {
	mosaicTimeout: false,
    init: function() {
		theme.initSquareProductImages();
		theme.adjustCollectionItemHeight();
        theme.initComments();
		theme.initMenuAffix();
		theme.initDropdownMenu();
		theme.initMobileMenu();
		theme.initTouchMenu();
        theme.initCollectionSwitching();
        theme.initSingleProductImageVariants();
        theme.initAddToCartSubmit();
		theme.initQuickProductFeatures();
        theme.initQuickView();
		theme.initWooQuickCartAjaxResponse();
        theme.initPostSmallSharrre();
        theme.initWooHTMLOverrides();
        theme.initSelectPickerLocations();
        theme.initCarousel();
        theme.minorWPOverrides();
        theme.initSidebarFilters();
        theme.initProductFeatures();
        theme.initCatalogItemAddToCart();
        theme.initQuantityField();
        theme.initReviewLinks();
		theme.initVCAddonsTitleBackgrounds();
		theme.initCarouselSwipe();
		theme.initNormalizeCarousels();
		theme.initHeaderSlider();
		theme.resetResponsiveHeader();
		theme.fixWooCatalogAlign();
		theme.initProductImageHoverZoom();
		theme.initBoxedParallax();
		theme.fixIE11Accelleration();
		theme.initCartTotalsUpdate();
		theme.initSaleLabelClick();
	},
    resizeEvent: function() {
		theme.initDropdownMenuWidth();
        theme.adjustCollectionItemHeight();
		theme.initNormalizeCarousels();
		theme.initHeaderSlider();
		theme.resetResponsiveHeader();
		theme.initProductFeatures();
    },
    initComments: function() {
        //form submit
        jQuery('#comment-submit').click(function(e){
            e.preventDefault();
			jQuery(this).parents('#commentform').submit();
        });
    },
	initSquareProductImages: function() {
		// Same width & height for images in products grid
		// --------------------------------------------------
		jQuery('.products-grid .item-single .image').each(function() {
			jQuery(this).height(jQuery(this).width());
		});
	},
	initDropdownMenuWidth: function() {
		
		// Set width to dropdown menu based on first level children
		// --------------------------------------------------
		jQuery('.dropdown-menu').each(function(){
			
			if(jQuery(window).outerWidth() > 992)
			{
				var sum=0;

				jQuery(this).children('.section').each(function(){ sum += jQuery(this).outerWidth(true); });

				if(sum > 1170) { sum = 1170; }

				if(sum > 0)
				{
					jQuery(this).width(sum + 6);
                    
                    //check if the item will overflow right in case of limited with mega menu
                    if(jQuery(this).parent('.limited-width').length > 0)
                    {
                        var offset = jQuery(this).offset();
                        var leftp = jQuery(window).outerWidth() - offset.left - (sum + 6);
                        
                        if(leftp < 0)
                        {
                            jQuery(this).css('left', leftp);
                        }
                                                
                    }
                    
					//set child left position
					if(jQuery(this).hasClass('default-dropdown'))
					{
						jQuery(this).find('.dropdown-menu').css('left', sum + 6);                
					}
				}
			}
            else
            {
                if(jQuery(this).parent('.limited-width').length > 0)
                {
                    jQuery(this).css('left', 'auto');
                }
            }
		});
	},
	adjustCollectionItemHeight: function() {
		
		if(jQuery(window).outerWidth() >= 768)
		{
			//collection items
			var items = jQuery('.products-grid.inline-4-grid .row .item-single')
			if(items.length > 0)
			{
				theme.resizeRowItemHeight(items, 4);
			}

			if(jQuery(window).outerWidth() >= 992)
			{
				//shortcode items 8 colummns
				var items = jQuery('.woocommerce.columns-8 .row .item-single');
				if(items.length > 0)
				{
					theme.resizeRowItemHeight(items, 8);
				}

				//shortcode items 7 colummns
				var items = jQuery('.woocommerce.columns-7 .row .item-single');
				if(items.length > 0)
				{
					theme.resizeRowItemHeight(items, 7);
				}
			}
			else
			{
				//shortcode items 8 colummns
				var items = jQuery('.woocommerce.columns-8 .row .item-single');
				if(items.length > 0)
				{
					theme.resizeRowItemHeight(items, 4);
				}

				//shortcode items 7 colummns
				var items = jQuery('.woocommerce.columns-7 .row .item-single');
				if(items.length > 0)
				{
					theme.resizeRowItemHeight(items, 4);
				}
			}

			//shortcode items 6 colummns
			var items = jQuery('.woocommerce.columns-6 .row .item-single');
			if(items.length > 0)
			{
				theme.resizeRowItemHeight(items, 6);
			}

			//shortcode items 5 colummns
			var items = jQuery('.woocommerce.columns-5 .row .item-single');
			if(items.length > 0)
			{
				theme.resizeRowItemHeight(items, 5);
			}

			//shortcode items 4 colummns
			var items = jQuery('.woocommerce.columns-4 .row .item-single');
			if(items.length > 0)
			{
				theme.resizeRowItemHeight(items, 4);
			}

			//shortcode items 3 colummns
			var items = jQuery('.woocommerce.columns-3 .row .item-single');
			if(items.length > 0)
			{
				theme.resizeRowItemHeight(items, 3);
			}

			//shortcode items 2 colummns
			var items = jQuery('.woocommerce.columns-2 .row .item-single');
			if(items.length > 0)
			{
				theme.resizeRowItemHeight(items, 2);
			}

			//slider items
			var items = jQuery('.products-grid.inline-3-grid.catalog .container .row .item-single');
			if(items.length > 0)
			{
				theme.resizeRowItemHeight(items, 3);
			}
		}
	},
	resizeRowItemHeight: function(items, columns) {
			
		var chunks = chunk(items, columns);
		for(var row in chunks)
		{			
			if(typeof chunks[row] !== "undefined")
            {
                chunks[row].height(''); //reset previous height
                var maxHeight = Math.max.apply(null, chunks[row].map(function ()
                {
					return jQuery(this).height();
                }).get());
				if(maxHeight > 0)
				{
					chunks[row].height(maxHeight);
					chunks[row].addClass('height-adjusted');
				}
            }
		}
	},
	initMenuAffix: function() {
		if(!jQuery('html').hasClass('touch'))
        {
            jQuery('.affix-data').affix({
                offset: {
                  top: 242
                }
            });
        }
	},
    initDropdownMenu: function() {
    
		// Bootstrap dropdown on hover
		// --------------------------------------------------
        jQuery('.nav li.dropdown').hover(function() {
	        jQuery(this).addClass('open');
	    }, function() {
	        jQuery(this).removeClass('open');
	    });        
        
        // Remove full width from mega menu items if it is not required there
		// --------------------------------------------------
        
        jQuery('.menu-item.full-width').each(function(){
			
			//remove un allowed dropdowns from sidemenus
						
			if(jQuery(this).find('.has-side-menu'))
			{
				jQuery(this).find('.has-side-menu .section .dropdown-menu.default-dropdown').each(function(){
					jQuery(this).parent().removeClass('dropdown');
					jQuery(this).siblings('a').removeClass('dropdown-toggle');
					jQuery(this).remove();
				});
			}
                        
            if(jQuery(this).find('.has-side-menu').length > 0)
            {
                return;
            }
            if(jQuery(this).find('.dropdown-special-offers').length > 0)
            {
                return;
            }
			if(jQuery(this).find('.widget_nav_menu').length === 3)	//make an exception for 3 nav menus
			{
				jQuery(this).removeClass('full-width');
                jQuery(this).addClass('limited-width');
				return;
			}
            if(jQuery(this).find('.section').length > 2)
            {
                return;
            }
            
            jQuery(this).removeClass('full-width');
            jQuery(this).addClass('limited-width');
        });
        
		
        // Three of Four children menu marking
		// --------------------------------------------------
		
        jQuery('.menu-item.full-width').each(function(){
                        
            if(jQuery(this).find('.section').length == 3 && jQuery(this).find('.widget_nav_menu').length != 3)
            {
				jQuery(this).find('.mega-menu').addClass('three');
            }
			else if(jQuery(this).find('.section').length > 3)
            {
                jQuery(this).find('.mega-menu').addClass('four');
            }
			
        });
		
		
        // Menu animation
		// --------------------------------------------------
        
        jQuery('.affix-data').on('affixed.bs.affix', function(){
            
            jQuery(this).attr('style', '');
            jQuery('.header .cart').attr('style', '');
            jQuery(this).animate({top : '0px'}, 350);
            jQuery('.header .cart').animate({top : '70px'}, 350);
        });      
        
        
		theme.initDropdownMenuWidth();
    },
    initMobileMenu: function() {
        
		// Open responsive menu submenus
		// --------------------------------------------------
		jQuery('.dropdown-toggle').on('click, tap', function(e) {

			if(jQuery(window).outerWidth() <= 992)
			{
				if(!jQuery(this).parent().hasClass('open-responsive'))
				{
					jQuery(this).parent().addClass('open-responsive');

					var close_link = '<a href="#" class="close-responsive"></a>';
					jQuery(this).parent().append(close_link);

					e.preventDefault();
				}
			}
		});            

		// Close responsive sub menu
		// --------------------------------------------------
		jQuery('.menu-item').on('click, tap', '.close-responsive', function(e) {

			if(jQuery(window).outerWidth() <= 992)
			{
				jQuery(this).parent().removeClass('open-responsive');
				jQuery(this).remove();

				return false;
			}
		});  

		// Show & hide responsive menu
		// --------------------------------------------------
		jQuery('.responsive-menu').on('click', function(e) {

			if(jQuery(window).outerWidth() <= 992)
			{
				var active = false;
				if(jQuery(this).hasClass('active'))
				{
					active = true;
				}

				jQuery('.container-fluid.menu, .search-content, .responsive-cart').removeClass('visible-responsive');
				jQuery('.responsive-search, .responsive-menu, .responsive-account').removeClass('active');

				if(!active)
				{
					jQuery(this).addClass('active');
					jQuery('.container-fluid.menu').addClass('visible-responsive');
				}

				e.preventDefault();
			}
		});

		// Show & hide responsive search
		// --------------------------------------------------
		jQuery('.responsive-search').on('click', function(e) {

			if(jQuery(window).outerWidth() <= 992)
			{
				var active = false;
				if(jQuery(this).hasClass('active'))
				{
					active = true;
				}

				jQuery('.container-fluid.menu, .search-content, .responsive-cart').removeClass('visible-responsive');
				jQuery('.responsive-search, .responsive-menu, .responsive-account').removeClass('active');

				if(!active)
				{
					jQuery(this).addClass('active');
					jQuery('.search-content').addClass('visible-responsive');
				}
				e.preventDefault();
			}
		});

		// Show & hide responsive accounts
		// --------------------------------------------------
		jQuery('.responsive-account').on('click', function(e) {

			if(jQuery(window).outerWidth() <= 992)
			{
				var active = false;
				if(jQuery(this).hasClass('active'))
				{
					active = true;
				}

				jQuery('.container-fluid.menu, .search-content, .responsive-cart').removeClass('visible-responsive');
				jQuery('.responsive-search, .responsive-menu, .responsive-account').removeClass('active');

				if(!active)
				{
					jQuery(this).addClass('active');
					jQuery('.responsive-cart').addClass('visible-responsive');
				}
				e.preventDefault();
			}
		});


		// Close menu on body click
		// --------------------------------------------------
		jQuery('.affix-wrapper, .products-grid, .vc_row').on('tap', function(e){
			if(jQuery(window).outerWidth() <= 992)
			{
				if(jQuery(e.target).parents('.responsive-account, .responsive-menu, .responsive-search, .visible-responsive').length === 0)
				{
					jQuery('.container-fluid.menu, .search-content, .responsive-cart').removeClass('visible-responsive');
					jQuery('.responsive-search, .responsive-menu, .responsive-account').removeClass('active');
				}
			}
		});

    },
	initTouchMenu: function() {
        if('ontouchstart' in document)
        {
						
            //no dropdown
			jQuery('.menu .nav > .menu-item:not(.dropdown) > a').on('tap', function(){
				return true;
			});
            
            //first level of dropdowns
            jQuery('.menu .nav > .menu-item.dropdown > .dropdown-toggle').on('tap', function(){
                                
                var current_item = jQuery(this);
				var current_id = jQuery(this).parent().attr('id');
								
                //if there are other open menus, hide them
                if(jQuery('.nav .menu-item.dropdown.open').not('#' + current_id).length > 0)
                {
                    jQuery('.nav .menu-item.dropdown.open').each(function(){
                		
						if(current_item.parent() !== jQuery(this))
                        {
                            jQuery(this).removeClass('open');
                        }
                    });
                }
                

				//add open class
                var parent = jQuery(this).parent();
                if(!parent.hasClass('open'))
                {
                    jQuery(this).parent().addClass('open');
                    return false;
                }
								
            });
            
            //second level of dropdowns
            jQuery('.menu .nav .menu-item.dropdown .dropdown > a').on('tap', function(){
              			  
                var current_item = jQuery(this).parent();
                //if there are other open menus, hide them
                if(jQuery('.nav .menu-item.dropdown .dropdown').not(this).length > 0)
                {
                    jQuery('.nav .menu-item.dropdown .dropdown.open').each(function(){
                        if(current_item.parent() !== jQuery(this))
                        {
                            jQuery(this).removeClass('open');
                        }
                    });
                }
                                
                if(!current_item.hasClass('open'))
                {
                    current_item.addClass('open');
                    return false;
                }
                
            });
            
            
            //close menu
			jQuery('.focus > .container, .header, .footer').on('tap', function(){
				var open = jQuery('.menu .nav .menu-item.dropdown.open');
				if(open.length > 0)
				{
					open.removeClass('open');
				}
			});			
            
        }
    },
    initCollectionSwitching: function() {
        
        jQuery('.dynamic-product-collection-switcher .dropdown-menu a').click(function(e){
            
            e.preventDefault();
            
            var menu_item = jQuery(this);
            var block = menu_item.attr('id').substring(18);
            var parent = menu_item.parents('.dynamic-product-collection-switcher');
            var parent_id = parent.attr('id');
            var count = parent.data('count');
            var columns = parent.data('columns');
            var type = parent.data('collection-type');
                      
            parent.find('.dropdown-menu li').removeClass('hidden');
            menu_item.parent().addClass('hidden');
            
            var item = jQuery('.block-' + parent_id + ' .' + block);
            if(item.html().length === 0)    //if there is no content load it with AJAX
            {
                var data = {
                    action: 'load_woo_shortcode',
                    property: block,
                    columns: columns,
                    count: count,
                    type: type
                };

                jQuery.post(plsh_js_params.ajaxurl, data, function(response) {
                    item.html(response);
                    theme.displayActiveCollection(item, parent_id);
                    theme.setActiveCollectionTitle(parent, menu_item, type);
                });
            }
            else
            {
                theme.displayActiveCollection(item, parent_id);
                theme.setActiveCollectionTitle(parent, menu_item, type);
            }
        
        });
    },
    displayActiveCollection: function(item, parent_id) {
        jQuery('.block-' + parent_id + ' .home-shortcode-block.active').fadeOut(300, function(){
            jQuery(this).removeClass('active');
            item.fadeIn('300').addClass('active');
			theme.adjustCollectionItemHeight();
			theme.initQuickProductFeatures();
			theme.initProductImageHoverZoom();
			item.find('.cycle-slideshow').cycle();
			theme.initQuickView();
        });
    },
    setActiveCollectionTitle: function(parent, menu_item, type) {
        var title = menu_item.text();
        parent.find('.title-wrapper .title > span').text(title);
        
        if(type == 'category')
        {
            parent.find('.view-all').attr('href', menu_item.attr('href'));
            var parent_id = parent.attr('id');
            jQuery('.view-all-' + parent_id).find('a').eq(0).attr('href', menu_item.attr('href'))
        }
    },
    initGoogleMaps: function() {
        
		if(plsh_js_params.maps_active)
		{
			// Map show/hide trigger
			// --------------------------------------------------
			jQuery('.show-map').on('click', function(e) {
				jQuery('.contacts-map .info').toggleClass('hidden');
				jQuery(this).html(jQuery(this).html() == plsh_js_params.texts.show_map ? plsh_js_params.texts.hide_map : plsh_js_params.texts.show_map);
				e.preventDefault();
			}); 

			var maps = jQuery('.google-map');
			if(maps.length > 0)
			{
				maps.each(function(){
					var id = jQuery(this).attr('id');
					var lat = jQuery(this).attr('data-lat');
					var lng = jQuery(this).attr('data-lng');
					var marker_lat = jQuery(this).attr('data-marker_lat');
					var marker_lng = jQuery(this).attr('data-marker_lng');
					var zoom = jQuery(this).attr('data-zoom');
					theme.loadMap(id, lat, lng, marker_lat, marker_lng, zoom);
				});
			}
		}
    },
    loadMap: function(id, lat, lng, marker_lat, marker_lng, zoom) {
            
            var mapOptions = {
                center: new google.maps.LatLng(lat,lng),
                zoom: parseInt(zoom),
                zoomControl: true,
                zoomControlOptions: {
                    style: google.maps.ZoomControlStyle.SMALL,
                },
                disableDoubleClickZoom: true,
                mapTypeControl: false,
                scaleControl: false,
                scrollwheel: false,
                panControl: false,
                streetViewControl: false,
                draggable : true,
                overviewMapControl: false,
                overviewMapControlOptions: {
                    opened: false,
                },
                mapTypeId: google.maps.MapTypeId.ROADMAP,
                styles: [
                    {
                        featureType: "landscape",
                        stylers: [
                            { saturation: -100 },
                            { lightness: 65 },
                            { visibility: "on" }
                        ]
                    },{
                        featureType: "poi",
                        stylers: [
                            { saturation: -100 },
                            { lightness: 51 },
                            { visibility: "simplified" }
                        ]
                    },{
                        featureType: "road.highway",
                        stylers: [
                            { saturation: -100 },
                            { visibility: "simplified" }
                        ]
                    },{
                        featureType: "road.arterial",
                        stylers: [
                            { saturation: -100 },
                            { lightness: 30 },
                            { visibility: "on" }
                        ]
                    },{
                        featureType: "road.local",
                        stylers: [
                            { saturation: -100 },
                            { lightness: 40 },
                            { visibility: "on" }
                        ]
                    },{
                        featureType: "transit",
                        stylers: [
                        { saturation: -100 },
                        { visibility: "simplified" }
                        ]
                    },{
                        featureType: "administrative.province",
                        stylers: [
                        { visibility: "off" }
                        ]
                    },{
                        featureType: "water",
                        elementType: "labels",
                        stylers: [
                            { visibility: "on" },
                            { lightness: -25 },
                            { saturation: -100 }
                        ]
                    },{
                        featureType: "water",
                        elementType: "geometry",
                        stylers: [
                            { hue: "#ffff00" },
                            { lightness: -25 },
                            { saturation: -97 }
                        ]
                    }
                ],
        };
        
        var mapElement = document.getElementById(id);
        var map = new google.maps.Map(mapElement, mapOptions);
        
        if(marker_lat.length > 0 && marker_lng.length > 0)
        {
            var locations = [
                ['home-marker', 'undefined', 'undefined', 'undefined', 'undefined', marker_lat, marker_lng, plsh_js_params.maps_marker]
            ];

            for (i = 0; i < locations.length; i++) 
            {
                if (locations[i][1] =='undefined'){ description ='';} else { description = locations[i][1];}
                if (locations[i][2] =='undefined'){ telephone ='';} else { telephone = locations[i][2];}
                if (locations[i][3] =='undefined'){ email ='';} else { email = locations[i][3];}
                if (locations[i][4] =='undefined'){ web ='';} else { web = locations[i][4];}
                if (locations[i][7] =='undefined'){ markericon ='';} else { markericon = locations[i][7];}
                marker = new google.maps.Marker({
                    icon: markericon,
                    position: new google.maps.LatLng(locations[i][5], locations[i][6]),
                    map: map,
                    title: locations[i][0],
                    desc: description,
                    tel: telephone,
                    email: email,
                    web: web
                });
                link = '';
            }
        }
    },
    initSingleProductImageVariants: function() {
        
        jQuery('input[name=variation_id]').change(function(){
            var variation = jQuery('input[name=variation_id]').val();
            if(variation !== false)
            {
                if(jQuery('.slider-variant-guide').length > 0) {
                   
                    var image_src = jQuery('.slider-variant-guide').attr('data-variant-' + variation);
                    if(image_src) {
                        jQuery('.main-slide').css('background-image', 'url(' + image_src + ')');
                    } else {
                        image_src = jQuery('.slider-variant-guide').attr('data-variant-default');
                        jQuery('.main-slide').css('background-image', 'url(' + image_src + ')');
                    }
                   
                } else {
                    var image = jQuery('#image-' + variation);
                    var index = jQuery('#single-product-slider .image').index(image);
                    if(index >= 0)
                    {
                        jQuery('#single-product-slider').cycle(index);
                    }
                }
            }
        });   
    },
    initAddToCartSubmit: function() {
        
        jQuery('form.cart .single_add_to_cart_button').click(function(){
            
			if(typeof jQuery(this).attr('disabled') === 'undefined')
			{
				jQuery(this).parents('form').eq(0).submit();
			}
            
            return false;
        });
    },
	initQuickProductFeatures: function() {
		
		if(jQuery(window).outerWidth() > 992)
		{
			/* Non touch */
			jQuery('.item-single.quick-features-enabled').hover(
				function()
				{
					jQuery(this).addClass('open');
				},
				function()
				{
					jQuery(this).removeClass('open');
				}
			);
			
			/* Touch */
			
			//prevent the link from working for non open items
			jQuery('.item-single.quick-features-enabled .link').on('tap', function(e){

				if(jQuery(this).parents('.item-single').hasClass('open'))
				{
					return true;
				}
				else
				{
					e.preventDefault();
				}
			});

			jQuery('.item-single.quick-features-enabled').not('.open').on('tap', function(){

				//remove other open items
				jQuery('.item-single.quick-features-enabled').removeClass('open');
				jQuery(this).addClass('open');

			});
			
		}
		
	},
    initQuickView: function() {
        		
		// Show & hide Quickview
		// --------------------------------------------------
		jQuery('.btn-quickview').on('click', function(e) {
			
            e.stopPropagation();
            
            jQuery('.focus').attr('class', 'focus out-of-focus');
                        
            var loader = '<div class="quickview-loader"><i class="fa fa-spinner fa-spin-custom"></i></div>';
            jQuery('body').prepend(loader);
                        
            var id = jQuery(this).parents('.item-single').attr('data-product-id');
            
            var data = {
                action: 'load_woo_quickview',
                id: id
            };

            var xhr = jQuery.post(plsh_js_params.ajaxurl, data, function(response) {    
                jQuery('body > .quickview-loader').remove();
                jQuery('body').prepend(response);
                jQuery('.quickview .selectpicker').selectpicker();
                jQuery('.quickview .cycle-slideshow').cycle();
                theme.initSingleProductImageVariants();                
                theme.initQuickviewAddToCart();
				theme.initQuantityField();
				
				// Set Quickview column height
				// --------------------------------------------------
				jQuery('.quickview').each(function() {
					jQuery('.quickview .col').height(jQuery(this).height());
				});
				
				jQuery('body').trigger('woo_quickview_loaded');
            });
            
            jQuery('.out-of-focus').click(function(){
                jQuery(this).removeClass('out-of-focus');
                jQuery('.quickview').remove();
                jQuery('.quickview-loader').remove();
                xhr.abort();
            });
            
			e.preventDefault();
		});
        
		jQuery('body').on('click', '.quickview .close', function(e) {
			jQuery('.focus').attr('class', 'focus');
			jQuery('.quickview').remove();
			e.preventDefault();
		});
        
    },
    initQuickviewAddToCart: function() {
        
        jQuery('.quickview .single_add_to_cart_button').click(function(){
            
			var loader = '<div class="add-to-cart-loader"><i class="fa fa-spinner fa-spin-custom"></i><i class="fa fa-check"></i></div>';
			jQuery('.quickview .more').append(loader);
			
            var form = jQuery('.quickview form').serialize();
            var url = jQuery('.quickview').attr('data-form-url');
            jQuery.post(url, form, function(response) {

				jQuery('.quickview .add-to-cart-loader').addClass('done');
				setTimeout(function(){
					jQuery('.quickview .add-to-cart-loader').fadeOut(200).remove();
				}, 5000);

				var data = { action: 'get_cart' };
                jQuery.post(plsh_js_params.ajaxurl, data, function(response) {
                    jQuery('.cart-content').html(response);
                });
                
            });
            
            return false;
        });
    },
	initWooQuickCartAjaxResponse: function() {	//hack. on every
		jQuery(document).ajaxComplete(function(response, jqXHR, plainObject) {
		
			if(typeof jqXHR.responseJSON != "undefined" && typeof jqXHR.responseJSON.fragments != "undefined")
			{
				jQuery('.cart-content').html(jqXHR.responseJSON.fragments['plsh-cart-contents']);
			}
		
		});
	},
    initPostSmallSharrre: function() {
        jQuery('.shareme').sharrre({
            share: {
                twitter: true,
                facebook: true,
                googlePlus: true,
                pinterest: true,
                linkedin: true
            },
            template: '<div class="box"><div class="left"><strong>{total}</strong> shares</div><div class="right"><a href="#" class="sharrre-facebook"><i class="fa fa-facebook-square"></i></a><a href="#" class="sharrre-twitter"><i class="fa fa-twitter-square"></i></a><a href="#" class="sharrre-googleplus"><i class="fa fa-google-plus-square"></i></a><a href="#" class="sharrre-pinterest"><i class="fa fa-pinterest-square"></i></a><a href="#" class="sharrre-linkedin"><i class="fa fa-linkedin-square"></i></a></div></div>',
            enableHover: false,
            enableTracking: true,
            urlCurl: plsh_js_params.ajaxurl + '?action=sharrre',
			buttons: { pinterest: { media: jQuery('.shareme').data('image'), description: jQuery('.shareme').data('text') } },
            render: function(api, options){
                jQuery(api.element).on('click', '.sharrre-twitter', function() {
                  api.openPopup('twitter');
                });
                jQuery(api.element).on('click', '.sharrre-facebook', function() {
                  api.openPopup('facebook');
                });
                jQuery(api.element).on('click', '.sharrre-googleplus', function() {
                  api.openPopup('googlePlus');
                });
                jQuery(api.element).on('click', '.sharrre-pinterest', function() {
                  api.openPopup('pinterest');
                });
                jQuery(api.element).on('click', '.sharrre-linkedin', function() {
                  api.openPopup('linkedin');
                });
            }
        });
    },
    initWooHTMLOverrides: function() {
        if(jQuery('body').hasClass('woocommerce-cart') || jQuery('body').hasClass('woocommerce-account') || jQuery('body').hasClass('woocommerce-checkout'))
        {
            jQuery('.woocommerce-order-details > h2, .cart_totals > h2, .woocommerce-account .woocommerce > h2, .woocommerce-billing-fields > h3, #order_review_heading, .woocommerce header > h2, .woocommerce-account form legend, .woocommerce-checkout .woocommerce > h2, #customer_login .col-1 > h2, #customer_login .col-2 > h2').each(function(){
                //add span to title to avoid overriding the php file
                var item_text = jQuery(this).text();
                jQuery(this).html('<span>' + item_text + '</span>');
            });
			
			if(jQuery('.woocommerce-shipping-fields h3').children('label').length == 0)
			{
				var item_text = jQuery('.woocommerce-shipping-fields h3').text();
                jQuery('.woocommerce-shipping-fields h3').html('<span>' + item_text + '</span>');
			}
        }
        if(jQuery('body').hasClass('woocommerce-wishlist'))
        {
            jQuery('.yith-wcwl-share-title, .wishlist-title h2').each(function(){
                //add span to title to avoid overriding the php file
                var item_text = jQuery(this).text();
                jQuery(this).html('<span>' + item_text + '</span>');
            });
        }
		if(jQuery('body').hasClass('yith-request-quote'))
        {
			jQuery('.yith-ywraq-mail-form-wrapper h3').each(function(){
                //add span to title to avoid overriding the php file
                var item_text = jQuery(this).text();
                jQuery(this).html('<span>' + item_text + '</span>');
            });
		}
    },
    initSelectPickerLocations: function() {
        
		//for woocommerce variants in cases where not all variations are used
		
		jQuery( '.variations_form' ).on( 'woocommerce_variation_select_change', function () {
			setTimeout(function(){
				jQuery('.variations_form  .selectpicker').selectpicker('refresh'); 
			}, 100);
		} );
		
		//trigger woo focus event on selectpicker click
		jQuery( '.variations_form' ).on('click', '.bootstrap-select', function(){
			jQuery(this).siblings('.selectpicker').trigger('focusin');
		});
		
		
		//Composite product support
		jQuery('.composite_form').on('wc-composite-component-loaded', function(){
			
			jQuery('.composite_form select').selectpicker();
			
		});
		
		
		//update selectpicker on variant update
		jQuery( '.variations_form' ).on( 'woocommerce_update_variation_values', function () {
			jQuery('.variations_form  .selectpicker').selectpicker('refresh'); 
		} );
		
        //for 3rdparty markup        
        jQuery('.widget_layered_nav select, .widget_product_categories select').selectpicker();
        jQuery('.woocommerce-shipping-calculator select').selectpicker();
		jQuery('.sidebar .sidebar-item select').selectpicker();
        
    },
    initCarousel: function() {
        // Start carousel
        // --------------------------------------------------
	   	jQuery('.carousel').carousel({
			pause: true,
			interval: false
		});
    },
    minorWPOverrides: function() {
        jQuery(".wp-caption").removeAttr('style');
    },
    initSidebarFilters: function() {
        // Sidebar filter active state trigger
		// --------------------------------------------------
		jQuery('.sidebar .filter-item input:checkbox').change(function () {
			if (jQuery(this).is(':checked')) {
				jQuery(this).parents().eq(1).addClass('active');
			} else {
				jQuery(this).parents().eq(1).removeClass('active');
			}
		});
    },
    initProductFeatures: function() {
        // Catalog item features height for vertical centering
		// --------------------------------------------------
		
		if(jQuery(window).outerWidth() >= 768)
		{
			jQuery('.features .feature').each(function(){
				var h = jQuery(this).height();
				jQuery(this).children().height(h);
			});
		}
		else
		{
			jQuery('.features .feature').each(function(){
				jQuery(this).children().css('height', 'auto');
			});
		}
    },
    initCatalogItemAddToCart: function() {
        
        jQuery('.item-single .add_to_cart_button').click(function(e){
            jQuery( document ).ajaxSuccess(function(event, xhr, settings) {
                
                //check if this is add to car request
                if(settings.data.indexOf('woocommerce_add_to_cart') > -1)
                {
                    if(typeof xhr.responseJSON.fragments['plsh-cart-contents'] !== "undefined")
                    {
                        jQuery('.cart-content').html(xhr.responseJSON.fragments['plsh-cart-contents']);
                    }
                }           
            });
        });
        
    },
    initQuantityField: function() {
        
		jQuery('.woocommerce').on('click', '.quantity .plus', function(){
            var quantity = jQuery(this).parent().siblings('input[type=number]');
            var newQuantity = parseInt(quantity.val()) + 1;
            quantity.val(newQuantity);
			quantity.trigger('change');
            return false;
        });
        
        jQuery('.woocommerce').on('click', '.quantity .minus', function(){  
            var quantity = jQuery(this).parent().siblings('input[type=number]');
            var oldQuantity = parseInt(quantity.val());
            if(oldQuantity > 1)
            {
                var newQuantity = oldQuantity - 1;
                quantity.val(newQuantity);
				quantity.trigger('change');
            }
            return false;
        });
    },
    initReviewLinks: function() {
        if(jQuery('body').hasClass('single-product'))
        {
            jQuery('.details .reviews .rating-item > a').click(function(){
                
                jQuery('.woocommerce-tabs .reviews_tab a').trigger('click');
                jQuery('html,body').animate({scrollTop: jQuery('#tab-reviews').offset().top-50},'300'); 
               
                return false;
            });
        }
    },
	initVCAddonsTitleBackgrounds: function() {
		jQuery('.upb_row_bg').each(function(){
			
			var color = jQuery(this).css('background-color');
			jQuery(this).parent().find('.title-wrapper a, .container-title .view-all').css('background-color', color);
			
		});
	},
	initCarouselSwipe: function() {
		if(jQuery('html').hasClass('touch')) {
		
			jQuery('.carousel').swiperight(function() {
				jQuery(this).carousel('prev');
			});
			
			jQuery('.carousel').swipeleft(function() {
				jQuery(this).carousel('next');
			});
			
		}
	},
	initNormalizeCarousels: function() {
		
		if(jQuery(window).outerWidth() >= 768)
		{
			jQuery('.carousel').each(function(){

				var items = jQuery(this).find('.item'), //grab all slides
				heights = [], //create empty array to store height values
				tallest; //create variable to make note of the tallest slide

				if (items.length) 
				{
					theme.normalizeCarousels(items, heights, tallest);
				}

			});
		}
	},
	normalizeCarousels: function(items, heights, tallest) {
		items.each(function() { //add heights to array
			jQuery(this).attr('style', '');
			heights.push(jQuery(this).height()); 
		});
		tallest = Math.max.apply(null, heights); //cache largest value
		items.each(function() {
			jQuery(this).css('min-height',tallest + 'px');
		});
	},
	initHeaderSlider: function() {
		if(jQuery('.header-wrapper').length > 0)
		{
			jQuery('.header-wrapper').css('height', jQuery(window).innerHeight());
		}
	},
	resetResponsiveHeader: function() {
		
		if(jQuery('.header').hasClass('logo-left'))
		{
			if(jQuery('body').outerWidth()+15 < 993)
			{
				jQuery('.header .logo').before(jQuery('.header .search'));
				
				jQuery('.header .logo').removeClass('logo-left');
				
				jQuery('.header').addClass('order-reset');
			}
			else
			{
				if(jQuery('.header').hasClass('order-reset'))
				{
					jQuery('.header .logo').after(jQuery('.header .search'));
					jQuery('.header .logo').after(jQuery('.header .cart'));
					
					jQuery('.header .logo').addClass('logo-left');
					
					jQuery('.header').removeClass('order-reset');
				}
			}
		}
		if(jQuery('.header').hasClass('logo-right'))
		{
			if(jQuery(window).outerWidth()+15 < 993)
			{
				jQuery('.header .logo').after(jQuery('.header .cart'));
				jQuery('.header .logo').before(jQuery('.header .search'));
				
				jQuery('.header .logo').removeClass('logo-right');
				jQuery('.header .cart').removeClass('cart-left');
				
				jQuery('.header').addClass('order-reset');
			}
			else
			{
				jQuery('.header .cart').after(jQuery('.header .search'));
				jQuery('.header .search').after(jQuery('.header .logo'));
				
				jQuery('.header .logo').addClass('logo-right');
				jQuery('.header .cart').addClass('cart-left');
				
				jQuery('.header').removeClass('order-reset');
			}
		}
	},
	fixWooCatalogAlign: function() {
		
		if(
			jQuery('body').hasClass('post-type-archive-product')
			||
			jQuery('body').hasClass('tax-product_cat')
			||
			jQuery('body').hasClass('tax-product_tag')
			)
		{
			var catalog = jQuery('.catalog.products-grid > .container');
			
			if(catalog.find('.col').length > 0 && catalog.find('.col').length < 3)
			{
				var missing = 3 - catalog.find('.col').length;
				
				for(var i=1; i <= 3; i++)
				{
					catalog.find('.row').append('<div class="col"></div>');
				}
				
			}
			
		}	
	},
	initProductImageHoverZoom: function() {
		
		jQuery('.item-single.zoom-enabled, .image-wrapper.zoom-enabled').hover(
			function() {
				jQuery(this).find('.image').stop(true).animate({
					backgroundSize: '115%'
				}, 200);
			},
			function() {
				jQuery(this).find('.image').animate({
					backgroundSize: '100%'
				}, 200);
			}
		);
	},
	initBoxedParallax: function() {
				
		if(plsh_js_params.use_parallax && plsh_js_params.background_mode === 'boxed')
		{
			var bg1 = document.getElementById('parallax-bg-2');
			var bg2 = document.getElementById('parallax-bg-1');

			if(bg1 !== null && bg2 !== null)
			{
				window.onload = function() {
					window.onscroll = function() {
						
					  var posX = (document.documentElement.scrollLeft) ? document.documentElement.scrollLeft : window.pageXOffset;
					  var posY = (document.documentElement.scrollTop) ? document.documentElement.scrollTop : window.pageYOffset;

					  var bg1parallax = calcParallax(400, 2, posY);
					  bg1.style.backgroundPosition = bg1parallax + "px" + " 0";

					  var bg2parallax = calcParallax(400, 6, posY);
					  bg2.style.backgroundPosition = bg2parallax + "px" + " 0";

					}
				}
			}
		}
	},
	initCartTotalsUpdate: function() {
		jQuery(document.body).on('updated_cart_totals', function(){
			 jQuery('.cart_totals > h2').each(function(){
                //add span to title to avoid overriding the php file
                var item_text = jQuery(this).text();
                jQuery(this).html('<span>' + item_text + '</span>');
            });
		});
	},
	fixIE11Accelleration: function() {
		if(navigator.userAgent.match(/MSIE 10/i) || navigator.userAgent.match(/Trident\/7\./) || navigator.userAgent.match(/Edge\/12\./)) {
		  jQuery('body').on("mousewheel", function () {
		    event.preventDefault();
		    var wd = event.wheelDelta;
		    var csp = window.pageYOffset;
		    window.scrollTo(0, csp - wd);
		  });
		}
	},
	initSaleLabelClick: function() {
		jQuery('.item-single .offer-tag').click(function(){
			var location = jQuery(this).parent('.item-single').find('.image-wrapper .link').attr('href');
			if (location.length > 0) {
				window.location.replace(location);
			}
		});
	}
};

//split array in chunks
function chunk (arr, len) {

  var chunks = [],
      i = 0,
      n = arr.length;

  while (i < n) {
    chunks.push(arr.slice(i, i += len));
  }

  return chunks;
}

function calcParallax(tileheight, speedratio, scrollposition) {
  //    by Brett Taylor http://inner.geek.nz/
  //    originally published at http://inner.geek.nz/javascript/parallax/
  //    usable under terms of CC-BY 3.0 licence
  //    http://creativecommons.org/licenses/by/3.0/
  return ((tileheight) - (Math.floor(scrollposition / speedratio) % (tileheight+1)));
}