<?php

if(!class_exists('PlanetshineTheme'))
{
	class PlanetshineTheme {

		function __construct() {

			/* Theme Specific Actions */
			add_action( 'after_setup_theme', array($this, 'setup'));
			add_action( 'after_setup_theme', array($this, 'init_less'));
			add_action( 'wp_enqueue_scripts', array($this, 'add_stylesheets'), 11 );
			add_action( 'wp_enqueue_scripts', array($this, 'add_scripts'));
			add_action( 'admin_enqueue_scripts', array($this, 'widget_upload_enqueue'));
			add_action( 'wp_default_scripts', array($this, 'print_scripts_in_footer'));
			add_action( 'parse_query', array($this, 'wpse_71157_parse_query'));  //fix query parse bug
			add_action( 'widgets_init', array($this, 'add_widgets'));
			add_action( 'add_meta_boxes', array($this, 'post_meta_boxes') );
			add_action( 'save_post', array($this, 'post_save_postdata'));
			add_action( 'wp_ajax_sharrre', array($this, 'sharrre_callback'));
			add_action( 'wp_ajax_nopriv_sharrre', array($this, 'sharrre_callback'));
			add_action( 'tgmpa_register', array($this, 'register_required_plugins'));

			/* Framework Actions */
			add_action( 'customize_register', 'plsh_customize_register' );
			add_action( 'wp_head', 'plsh_header_output');
			add_action( 'wp_head', 'plsh_output_theme_version' );
			add_filter( 'less_vars', 'plsh_map_visual_settings_to_less', 10, 2 );

			/* Filters */
			add_filter( 'wp_title', array($this, 'wp_title_for_home') , 10, 2 );
			add_filter( 'excerpt_length', array($this, 'custom_excerpt_length'), 999 );
			add_filter( 'excerpt_more', array($this, 'custom_excerpt_more'), 999 );
			add_filter( 'img_caption_shortcode', array($this, 'fix_image_margins'), 10, 3);
			add_filter( 'constellation_sidebar_args', array($this, 'setup_constellation_sidebar'));
			add_filter( 'widget_title', array($this, 'widget_title_force'));

		}

		/*
		 * Init main theme features, declare what's supported, load shortcodes
		 */
		function setup() 
		{
			/* Make theme available for translation.
			 * Translations can be added to the /languages/ directory.
			 */
			load_theme_textdomain( 'polaris', get_template_directory() . '/languages' );
			if(is_child_theme())
			{
				load_child_theme_textdomain( 'polaris', get_stylesheet_directory() . '/languages' );
			}

			// This theme styles the visual editor with editor-style.css to match the theme style.
			add_theme_support( 'woocommerce' );
			add_theme_support( 'automatic-feed-links' );
			add_post_type_support( 'page', 'excerpt' );
			add_theme_support( 'post-thumbnails' );
			// commented out since WP 4.9 - an error occurs which doesn't allow to display customizer's Publish button
//			add_theme_support( 'custom-background' );

			register_nav_menu( 'primary-menu', __( 'Primary Menu', 'polaris' ) );
			register_nav_menu( 'header-menu', __( 'Header Menu', 'polaris' ) );

			plsh_add_image_sizes();

			if(!plsh_is_woocommerce_active())
			{
				$this->remove_woocommerce_settings();
			}

			$sidebars = plsh_gs('sidebars');
			if(!empty($sidebars))
			{
				foreach($sidebars as $sidebar)
				{
					register_sidebar( $sidebar );
				}
			}

			//set default values for ajax live search labels. If they exists, this will do nothing which is correct
			add_option('yith_wcas_search_submit_label', '&#xf002;');
			add_option('yith_wcas_search_input_label', 'Live search');

			//set default position for wishlist
			add_option('yith_wcwl_button_position', 'shortcode');

			//set catalog mode as disabled by default
			add_option('ywctm_enable_plugin', 'no');
			add_option('ywctm_admin_view', 'no');
			
			
			include_once( get_template_directory() . '/theme/includes/' . 'vc-content-blocks.php');
			include_once( get_template_directory() . '/theme/includes/' . 'shortcodes.php');


			//content blocks
			if(plsh_is_woocommerce_active())
			{
				add_shortcode( 'special_product_list', 'sc_special_product_list' );
				add_shortcode( 'product_category_list', 'sc_product_category_list' );
				add_shortcode( 'product_slider', 'sc_product_slider' );
				add_shortcode( 'product_features', 'sc_product_features' );
			}

			add_shortcode( 'special_offers', 'sc_special_offers' );
			add_shortcode( 'offer_item', 'sc_offer_item' );
			add_shortcode( 'product_brands', 'sc_product_brands' );
			add_shortcode( 'brand_item', 'sc_brand_item' );
			add_shortcode( 'contact_map', 'sc_contact_map' );
			add_shortcode( 'welcome_block', 'sc_welcome_block' );
			add_shortcode( 'title_block', 'sc_title_block' );
			add_shortcode( 'post_list', 'sc_post_list' );
			add_shortcode( 'banner250', 'sc_banner250' );
			add_shortcode( 'banner468', 'sc_banner468' );
			add_shortcode( 'banner728', 'sc_banner728' );

		}

		
		/*
		 *  Init LESS stylsheets
		 */
		function init_less() 
		{
			$upload_dir = wp_upload_dir();
			if(plsh_gs('enable_css_mode') == 'off' && (is_writable($upload_dir['basedir']) && class_exists( 'wp_less' ) && function_exists('file_get_contents') && function_exists('file_put_contents')))
			{
				add_action( 'init', array( 'wp_less', 'instance' ) );
				update_option('plsh_use_less', 1);
			}
			else
			{
				update_option('plsh_use_less', 0);
			}
		}

		/*
		 * Include stylsheets
		 */
		function add_stylesheets() 
		{
			wp_enqueue_style( 'plsh-bootstrap', PLSH_CSS_URL . 'bootstrap.min.css' );
			wp_enqueue_style( 'plsh-font-awesome', PLSH_CSS_URL . 'font-awesome.min.css' );

			if(get_option('plsh_use_less') == 1)
			{
				wp_enqueue_style( 'plsh-main-less', PLSH_LESS_URL . 'main.less'); 
			}
			else
			{
				wp_enqueue_style( 'plsh-main-css', PLSH_CSS_URL . 'main.css' );
			}

			wp_enqueue_style( 'plsh-awesome-bootstrap-checkbox', PLSH_CSS_URL . 'awesome-bootstrap-checkbox.css' );
			wp_enqueue_style( 'plsh-bootstrap-select', PLSH_CSS_URL . 'bootstrap-select.css' );
			wp_enqueue_style( 'plsh-wordpress_style', PLSH_CSS_URL . 'wordpress.css' );
			wp_enqueue_style( 'plsh-style', get_bloginfo( 'stylesheet_url' ) );   
			wp_enqueue_style( 'plsh-google-fonts', plsh_google_fonts_url(), array(), null );

			//don't use Constellation stylesheet
			wp_dequeue_style('cm-frontend');
		}

		/*
		 * Include scripts
		 */
		function add_scripts() 
		{
			wp_enqueue_script( 'plsh-modernizr', PLSH_JS_URL . 'vendor/modernizr.min.js');
			wp_enqueue_script( 'plsh-bootstrap', PLSH_JS_URL . 'vendor/bootstrap.js', array( 'jquery' ), false, true);
			wp_enqueue_script( 'plsh-bootstrap-select', PLSH_JS_URL . 'vendor/bootstrap-select.min.js', array('jquery', 'plsh-bootstrap') );
			wp_enqueue_script( 'plsh-cycle2', PLSH_JS_URL . 'vendor/jquery.cycle2.min.js', array( 'jquery' ), false, true);
			wp_enqueue_script( 'plsh-cycle2-swipe', PLSH_JS_URL . 'vendor/jquery.cycle2.swipe.min.js', array( 'jquery', 'plsh-cycle2' ), false, true);
			wp_enqueue_script( 'plsh-jquery-mobile', PLSH_JS_URL . 'vendor/jquery.mobile.custom.min.js', array( 'jquery', 'plsh-bootstrap' ), false, true);

			if(plsh_gs('gmaps_api_key') && strlen(plsh_gs('gmaps_api_key')) > 0)
			{
				wp_enqueue_script( 'gmaps', 'https://maps.googleapis.com/maps/api/js?key=' . plsh_gs('gmaps_api_key') . '&sensor=false&extension=.js', array(), false, true);
			}

			wp_enqueue_script( 'plsh-sharrre', PLSH_JS_URL . 'vendor/jquery.sharrre.min.js', array( 'jquery' ), false, true);
			wp_enqueue_script( 'plsh-theme', PLSH_JS_URL . 'theme.js', array( 'jquery', 'plsh-sharrre' ), false, true);

			$ajax_object = array();
			$ajax_object['ajaxurl'] = admin_url( 'admin-ajax.php' );

			
			if(plsh_gs('gmaps_api_key') && strlen(plsh_gs('gmaps_api_key')) > 0)
			{
				$ajax_object['maps_active'] = true;
			}
			else
			{
				$ajax_object['maps_active'] = false;
			}

			$ajax_object['maps_marker'] = PLSH_IMG_URL . 'contacts-map-marker-2.png';
			$ajax_object['use_parallax'] = get_theme_mod('use-parallax', plsh_gs('use-parallax'));
			$ajax_object['background_mode'] = get_theme_mod('background_mode', plsh_gs('background_mode'));
			$ajax_object['texts']['show_map'] = __('Show map', 'polaris');
			$ajax_object['texts']['hide_map'] = __('Hide map', 'polaris');

			if(function_exists('icl_get_languages'))
			{
				$ajax_object['lang'] = ICL_LANGUAGE_CODE;
			}

			wp_localize_script( 'plsh-theme', 'plsh_js_params', $ajax_object );
		}

		/*
		 * Initialize widgets
		 */
		function add_widgets()
		{
			require_once( get_template_directory() . '/theme/widgets/' . 'polaris-recent-posts.php');
			require_once( get_template_directory() . '/theme/widgets/' . 'polaris-contacts-info.php');
			require_once( get_template_directory() . '/theme/widgets/' . 'polaris-newsletter-menu.php');
			require_once( get_template_directory() . '/theme/widgets/' . 'polaris-products.php');
			require_once( get_template_directory() . '/theme/widgets/' . 'polaris-dropdown-special-offers.php');
			require_once( get_template_directory() . '/theme/widgets/' . 'polaris-banner-large.php');

			register_widget( 'PolarisRecentPosts' );
			register_widget( 'PolarisContactsInfo' );
			register_widget( 'PolarisNewsletterMenu' );
			register_widget( 'PolarisProducts' );
			register_widget( 'PolarisDropdownSpecialOffers' );
			register_widget( 'PolarisBannerLarge' );
		}


		/*
		 * Add meta boxes
		 */
		function post_meta_boxes() 
		{
			add_meta_box(
				'post_settings',
				__('Post settings', 'polaris'),
				array($this, 'post_inner_meta_box'),
				'post'
			);

			global $post;
			// don't show page settings for shop
			if(plsh_is_woocommerce_active())
			{
				$shop_id = wc_get_page_id( 'shop' );
				if(wc_get_page_id( 'shop' ) == $post->ID) return;
			}

			//don't show page settings for blog & homepage
			if(get_option('show_on_front') == 'page')
			{
			//    if(get_option( 'page_on_front') == $post->ID) return;
				if(get_option( 'page_for_posts') == $post->ID) return;
			}

			add_meta_box(
				'page_settings',
				__('Page settings', 'polaris'),
				array($this, 'page_inner_meta_box'),
				'page'
			);

			if(plsh_is_woocommerce_active())
			{
				add_meta_box(
					'page_settings',
					__('Additional properties', 'polaris'),
					array($this, 'product_inner_meta_box'),
					'product'
				);
			}
		}

		/*
		 * Handle meta box save
		 */
		function post_save_postdata( $post_id ) 
		{
			// Check if the current user is authorised to do this action. 
			if ( 'post' == plsh_get($_POST, 'post_type') || 'post' == plsh_get($_GET, 'post_type') || 'product' == plsh_get($_GET, 'post_type')) 
			{
				if ( ! current_user_can( 'edit_page', $post_id ) )
					  return;
			} 
			else
			{
				if ( ! current_user_can( 'edit_post', $post_id ) )
					  return;
			}

			//Nonce verfy
			if ( ! isset( $_POST['page_noncename'] ) || ! wp_verify_nonce( $_POST['page_noncename'], plugin_basename( __FILE__ ) ) )
				return;


			$post_ID = $_POST['post_ID'];
			$type = get_post_type($post_ID);
			if($type == 'post')
			{
				$post_style = trim(sanitize_text_field( $_POST['post_style'] ));

				update_post_meta($post_ID, 'post_style', $post_style);
			}
			else if($type == 'page')
			{
				if(get_option( 'page_on_front') != $post_ID)
				{
					$show_share  = ( !empty($_POST['show_share']) ? sanitize_text_field($_POST['show_share']) : false);
					$custom_sidebar = trim(sanitize_text_field( $_POST['custom_sidebar'] ));

					update_post_meta($post_ID, 'show_share', $show_share);
					update_post_meta($post_ID, 'custom_sidebar', $custom_sidebar);

				}

				$page_rev_slider = trim(sanitize_text_field( $_POST['page_rev_slider'] ));
				update_post_meta($post_ID, 'page_rev_slider', $page_rev_slider);
			}
			else if($type == 'product')
			{
				$product_label_color = trim(sanitize_text_field( $_POST['product_label_color'] ));
				$product_label_text = trim(sanitize_text_field( $_POST['product_label_text'] ));
				$use_product_notes = trim(sanitize_text_field( $_POST['use_product_notes'] ));
				$product_notes = trim( plsh_kses_widget_html_field($_POST['product_notes'] ));

				update_post_meta($post_ID, 'product_label_color', $product_label_color);
				update_post_meta($post_ID, 'product_label_text', $product_label_text);
				update_post_meta($post_ID, 'use_product_notes', $use_product_notes);
				update_post_meta($post_ID, 'product_notes', $product_notes);
			}
		}


		/*
		 * Post inner meta box
		 */
		function post_inner_meta_box( $post ) 
		{
			// Use nonce for verification
			wp_nonce_field( plugin_basename( __FILE__ ), 'page_noncename' );

			$post_style = get_post_meta( $post->ID, $key = 'post_style', $single = true );
			echo '<p>';
			echo '<label for="post_style">';
				 _e("Post style:", 'polaris');
			echo '</label><br/>';
			echo '<select id="post_style" name="post_style" value="' . esc_attr($post_style) . '"" style="min-width: 300px;">'
					. '<option value="global" ' . ($post_style == 'global' ? 'selected="selected"' : '')  . '>' . __('Global theme setting', 'polaris') . '</option>'
					. '<option value="sidebar"' . ($post_style == 'sidebar' ? 'selected="selected"' : '')  . '>' . __('With sidebar', 'polaris') . '</option>'
					. '<option value="no-sidebar"' . ($post_style == 'no-sidebar' ? 'selected="selected"' : '')  . '>' . __('Full width', 'polaris') . '</option>'
				. '</select>';
			echo '</p>';
		}

		/*
		 * Page inner meta box
		 */
		function page_inner_meta_box( $post ) 
		{
			// Use nonce for verification
			wp_nonce_field( plugin_basename( __FILE__ ), 'page_noncename' );

			if(get_option( 'page_on_front') != $post->ID)
			{
				$show_share = get_post_meta( $post->ID, $key = 'show_share', $single = true );
				echo '<p>';
				echo '<input type="checkbox" id="show_share" name="show_share" ' . ($show_share == true ? 'checked' : '')  . ' />';
				echo '<label for="show_share">';
					 _e("Show share icons", 'polaris');
				echo '</label>';
				echo '</p>';


				$page_sidebars = plsh_gs('sidebars');
				if(!empty($page_sidebars))
				{
					$custom_sidebar = get_post_meta( $post->ID, $key = 'custom_sidebar', $single = true );
					echo '<p>';
					echo '<label for="custom_sidebar">';
						 _e("Custom sidebar (for pages that have a sidebar):", 'polaris');
					echo '</label><br/>';
					echo '<select id="custom_sidebar" name="custom_sidebar" value="' . esc_attr($custom_sidebar) . '"" style="min-width: 300px;">';

					echo '<option value="global">' . __('Global theme setting', 'polaris') . '</option>';
					foreach($page_sidebars as $sidebar)
					{
						$selected = ($sidebar['id'] == $custom_sidebar ? 'selected="selected"' : '' );
						echo '<option value="' . $sidebar['id'] . '"' . $selected .'>' . $sidebar['name'] . '</option>';
					}

					echo '</select>';
					echo '</p>';
				}
			}

			if(function_exists('set_revslider_as_theme')) 
			{ 
				$page_rev_slider = get_post_meta( $post->ID, $key = 'page_rev_slider', $single = true );

				$revSlider = new RevSlider();
				$all_sliders = $revSlider->getAllSliderAliases();

				echo '<p>';
				echo '<label for="page_rev_slider">';
					_e("Full page Revolution Slider (Optional):", 'polaris');
				echo '</label><br/>';

				echo '<select id="page_rev_slider" name="page_rev_slider" value="' . esc_attr($page_rev_slider) . '"" style="min-width: 300px;">';

					echo '<option value="disabled">' . __('Disabled', 'polaris') . '</option>';
					if(!empty($all_sliders))
					{
						foreach($all_sliders as $slider)
						{
							$selected = ($slider == $page_rev_slider ? 'selected="selected"' : '' );
							echo '<option value="' . $slider . '"' . $selected .'>' . $slider . '</option>';
						}	
					}

				echo '</select>';

				echo '</p>';        
			}

		}

		/*
		 * Product meta box
		 */
		function product_inner_meta_box( $post ) 
		{
			// Use nonce for verification
			wp_nonce_field( plugin_basename( __FILE__ ), 'page_noncename' );

			$product_label_color = get_post_meta( $post->ID, $key = 'product_label_color', $single = true );
			$product_label_text = get_post_meta( $post->ID, $key = 'product_label_text', $single = true );
			$use_product_notes = get_post_meta( $post->ID, $key = 'use_product_notes', $single = true );
			$product_notes = get_post_meta( $post->ID, $key = 'product_notes', $single = true );

			$colors = array(
				'red'		=> __('Red', 'polaris'),
				'green'		=> __('Green', 'polaris'),
				'purple'	=> __('Purple', 'polaris'),
				'gold'		=> __('Gold', 'polaris'),
				'blue'		=> __('Blue', 'polaris'),
			);

			echo '<p>';
			echo '<label for="product_label_color">';
				 _e("Product label", 'polaris');
			echo '</label><br/>';
			echo '<select id="product_label_color" name="product_label_color" value="' . esc_attr($product_label_color) . '"" style="min-width: 300px;">';

				echo '<option value="no_label">' . __('No label', 'polaris') . '</option>';

			foreach($colors as $key => $color)
			{
				$selected = ($key == $product_label_color ? 'selected="selected"' : '' );
				echo '<option value="' . $key . '"' . $selected .'>' . $color . '</option>';
			}
			echo '</select>';
			echo '</p>';

			echo '<p>';
			echo '<label for="product_label_text">';
				_e("Product label text (single short words work best)", 'polaris');
			echo '</label><br/>';
			echo '<input type="text" id="product_label_text" name="product_label_text" value="' . $product_label_text . '" style="min-width: 300px;"/>';
			echo '</p>';


			echo '<p>';
			echo '<label for="use_product_notes">';
				 _e("Notes to customers", 'polaris');
			echo '</label><br/>';
			echo '<select id="use_product_notes" name="use_product_notes" value="' . esc_attr($use_product_notes) . '"" style="min-width: 300px;">';

				echo '<option value="disabled"' . ('disabled' == $use_product_notes ? ' selected="selected"' : '' ) . '>' . __('Disabled', 'polaris') . '</option>';
				echo '<option value="use_global"' . ('use_global' == $use_product_notes ? ' selected="selected"' : '' ) . '>' . __('Use global setting (edit in theme settings)', 'polaris') . '</option>';
				echo '<option value="custom"' . ('custom' == $use_product_notes ? ' selected="selected"' : '' ) . '>' . __('Custom (edit below)', 'polaris') . '</option>';

			echo '</select>';
			echo '</p>';

			echo '<p>';
			echo '<label for="product_notes">';
				_e("Customer note content (HTML allowed)", 'polaris');
			echo '</label><br/>';
			echo '<textarea id="product_notes" name="product_notes" style="min-width: 300px;">' . $product_notes . '</textarea>';
			echo '</p>';
		}


		/*
		 * Register plugins for TGMPA
		 */
		function register_required_plugins()
		{
			/**
			 * Array of plugin arrays. Required keys are name and slug.
			 * If the source is NOT from the .org repo, then source is also required.
			 */
			$plugins = $this->get_bunlded_plugins();

			// Change this to your theme text domain, used for internationalising strings

			/**
			 * Array of configuration settings. Amend each line as needed.
			 * If you want the default strings to be available under your own theme domain,
			 * leave the strings uncommented.
			 * Some of the strings are added into a sprintf, so see the comments at the
			 * end of each line for what each argument will be.
			 */
			$config = array(
				'domain'       		=> 'polaris',         	// Text domain - likely want to be the same as your theme.
				'default_path' 		=> '',                         	// Default absolute path to pre-packaged plugins
				'menu'         		=> 'install-required-plugins', 	// Menu slug
				'has_notices'      	=> true,                       	// Show admin notices or not
				'is_automatic'    	=> false,					   	// Automatically activate plugins after installation or not
				'message' 			=> '',							// Message to output right before the plugins table
				'strings'      		=> array(
					'page_title'                       			=> __( 'Install Required Plugins', 'polaris' ),
					'menu_title'                       			=> __( 'Install Plugins', 'polaris' ),
					'installing'                       			=> __( 'Installing Plugin: %s', 'polaris' ), // %1$s = plugin name
					'oops'                             			=> __( 'Something went wrong with the plugin API.', 'polaris' ),
					'notice_can_install_required'     			=> _n_noop( 'This theme requires the following plugin: %1$s.', 'This theme requires the following plugins: %1$s.', 'polaris' ), // %1$s = plugin name(s)
					'notice_can_install_recommended'			=> _n_noop( 'This theme recommends the following plugin: %1$s.', 'This theme recommends the following plugins: %1$s.', 'polaris' ), // %1$s = plugin name(s)
					'notice_cannot_install'  					=> _n_noop( 'Sorry, but you do not have the correct permissions to install the %s plugin. Contact the administrator of this site for help on getting the plugin installed.', 'Sorry, but you do not have the correct permissions to install the %s plugins. Contact the administrator of this site for help on getting the plugins installed.', 'polaris' ), // %1$s = plugin name(s)
					'notice_can_activate_required'    			=> _n_noop( 'The following required plugin is currently inactive: %1$s.', 'The following required plugins are currently inactive: %1$s.', 'polaris' ), // %1$s = plugin name(s)
					'notice_can_activate_recommended'			=> _n_noop( 'The following recommended plugin is currently inactive: %1$s.', 'The following recommended plugins are currently inactive: %1$s.', 'polaris' ), // %1$s = plugin name(s)
					'notice_cannot_activate' 					=> _n_noop( 'Sorry, but you do not have the correct permissions to activate the %s plugin. Contact the administrator of this site for help on getting the plugin activated.', 'Sorry, but you do not have the correct permissions to activate the %s plugins. Contact the administrator of this site for help on getting the plugins activated.', 'polaris' ), // %1$s = plugin name(s)
					'notice_ask_to_update' 						=> _n_noop( 'The following plugin needs to be updated to its latest version to ensure maximum compatibility with this theme: %1$s.', 'The following plugins need to be updated to their latest version to ensure maximum compatibility with this theme: %1$s.', 'polaris' ), // %1$s = plugin name(s)
					'notice_cannot_update' 						=> _n_noop( 'Sorry, but you do not have the correct permissions to update the %s plugin. Contact the administrator of this site for help on getting the plugin updated.', 'Sorry, but you do not have the correct permissions to update the %s plugins. Contact the administrator of this site for help on getting the plugins updated.', 'polaris' ), // %1$s = plugin name(s)
					'install_link' 					  			=> _n_noop( 'Begin installing plugin', 'Begin installing plugins', 'polaris' ),
					'activate_link' 				  			=> _n_noop( 'Activate installed plugin', 'Activate installed plugins', 'polaris' ),
					'return'                           			=> __( 'Return to Required Plugins Installer', 'polaris' ),
					'plugin_activated'                 			=> __( 'Plugin activated successfully.', 'polaris' ),
					'complete' 									=> __( 'All plugins installed and activated successfully. %s', 'polaris' ), // %1$s = dashboard link
					'nag_type'									=> 'updated' // Determines admin notice type - can only be 'updated' or 'error'
				)
			);

			tgmpa( $plugins, $config );
		}

		/*
		 * Return list of bundled plugins
		 */
		public function get_bunlded_plugins()
		{
			return array(

				// This is an example of how to include a plugin pre-packaged with a theme
				array(
					'name'     				=> 'Visual Composer', // The plugin name
					'slug'     				=> 'js_composer', // The plugin slug (typically the folder name)
					'source'   				=> get_template_directory() . '/theme/plugins/' . 'js_composer.zip', // The plugin source
					'required' 				=> true, // If false, the plugin is only 'recommended' instead of required
					'version' 				=> plsh_get_bundled_plugin_version('js_composer'), // E.g. 1.0.0. If set, the active plugin must be this version or higher, otherwise a notice is presented
					'force_activation' 		=> false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch
					'force_deactivation' 	=> false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins
					'external_url' 			=> '', // If set, overrides default API URL and points to an external URL
				),
				array(
					'name'     				=> 'Ultimate Addons for Visual Composer', // The plugin name
					'slug'     				=> 'Ultimate_VC_Addons', // The plugin slug (typically the folder name)
					'source'   				=> get_template_directory() . '/theme/plugins/' . 'Ultimate_VC_Addons.zip', // The plugin source
					'required' 				=> true, // If false, the plugin is only 'recommended' instead of required
					'version' 				=> plsh_get_bundled_plugin_version('Ultimate_VC_Addons'), // E.g. 1.0.0. If set, the active plugin must be this version or higher, otherwise a notice is presented
					'force_activation' 		=> false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch
					'force_deactivation' 	=> false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins
					'external_url' 			=> '', // If set, overrides default API URL and points to an external URL
				),
				array(
					'name'     				=> 'Revolution Slider', // The plugin name
					'slug'     				=> 'revslider', // The plugin slug (typically the folder name)
					'source'   				=> get_template_directory() . '/theme/plugins/' . 'revslider.zip', // The plugin source
					'required' 				=> true, // If false, the plugin is only 'recommended' instead of required
					'version' 				=> plsh_get_bundled_plugin_version('revslider'), // E.g. 1.0.0. If set, the active plugin must be this version or higher, otherwise a notice is presented
					'force_activation' 		=> false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch
					'force_deactivation' 	=> false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins
					'external_url' 			=> '', // If set, overrides default API URL and points to an external URL
				),
				array(
					'name'     				=> 'Constellation Mega Menu for Polaris', // The plugin name
					'slug'     				=> 'constellation', // The plugin slug (typically the folder name)
					'source'   				=> get_template_directory() . '/theme/plugins/' . 'constellation.zip', // The plugin source
					'required' 				=> true, // If false, the plugin is only 'recommended' instead of required
					'version' 				=> '1.0.6', // E.g. 1.0.0. If set, the active plugin must be this version or higher, otherwise a notice is presented
					'force_activation' 		=> false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch
					'force_deactivation' 	=> false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins
					'external_url' 			=> '', // If set, overrides default API URL and points to an external URL
				),
				array(
					'name'     				=> 'Planetshine Demo Import', // The plugin name
					'slug'     				=> 'planetshine-demo-import', // The plugin slug (typically the folder name)
					'source'   				=> get_template_directory() . '/theme/plugins/' . 'planetshine-demo-import.zip', // The plugin source
					'required' 				=> true, // If false, the plugin is only 'recommended' instead of required
					'version' 				=> '1', // E.g. 1.0.0. If set, the active plugin must be this version or higher, otherwise a notice is presented
					'force_activation' 		=> true, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch
					'force_deactivation' 	=> true, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins
					'external_url' 			=> '', // If set, overrides default API URL and points to an external URL
				),
				array(
					'name'     				=> 'Woocommerce', // The plugin name
					'slug'     				=> 'woocommerce', // The plugin slug (typically the folder name)
					'required' 				=> true, // If false, the plugin is only 'recommended' instead of required
					'version' 				=> '2.5.5'
				),
				array(
					'name'     				=> 'Regenerate Thumbnails', // The plugin name
					'slug'     				=> 'regenerate-thumbnails', // The plugin slug (typically the folder name)
					'required' 				=> true, // If false, the plugin is only 'recommended' instead of required
					'version' 				=> ''
				), 
				array(
					'name'     				=> 'WooCommerce Ajax Search', // The plugin name
					'slug'     				=> 'yith-woocommerce-ajax-search', // The plugin slug (typically the folder name)
					'required' 				=> true, // If false, the plugin is only 'recommended' instead of required
					'version' 				=> '', // E.g. 1.0.0. If set, the active plugin must be this version or higher, otherwise a notice is presented
				),
				array(
					'name'     				=> 'WooCommerce Wishlist', // The plugin name
					'slug'     				=> 'yith-woocommerce-wishlist', // The plugin slug (typically the folder name)
					'required' 				=> true, // If false, the plugin is only 'recommended' instead of required
					'version' 				=> '', // E.g. 1.0.0. If set, the active plugin must be this version or higher, otherwise a notice is presented
				),
				array(
					'name'     				=> 'WooCommerce Request a Quote', // The plugin name
					'slug'     				=> 'yith-woocommerce-request-a-quote', // The plugin slug (typically the folder name)
					'required' 				=> false, // If false, the plugin is only 'recommended' instead of required
					'version' 				=> '', // E.g. 1.0.0. If set, the active plugin must be this version or higher, otherwise a notice is presented
				),

				array(
					'name'     				=> 'WooCommerce Catalog Mode', // The plugin name
					'slug'     				=> 'yith-woocommerce-catalog-mode', // The plugin slug (typically the folder name)
					'required' 				=> false, // If false, the plugin is only 'recommended' instead of required
					'version' 				=> '', // E.g. 1.0.0. If set, the active plugin must be this version or higher, otherwise a notice is presented
				),
				array(
					'name'     				=> 'Live Chat', // The plugin name
					'slug'     				=> 'yith-live-chat', // The plugin slug (typically the folder name)
					'required' 				=> false, // If false, the plugin is only 'recommended' instead of required
					'version' 				=> '', // E.g. 1.0.0. If set, the active plugin must be this version or higher, otherwise a notice is presented
				),
				array(
					'name'     				=> 'Contact Form 7', // The plugin name
					'slug'     				=> 'contact-form-7', // The plugin slug (typically the folder name)
					'required' 				=> false, // If false, the plugin is only 'recommended' instead of required
					'version' 				=> ''
				),            
			);
		}

		/*
		 * Callback for Sharrre plugin
		 */
		function sharrre_callback()
		{
			header('content-type: application/json');
			ob_start();
			//Sharrre by Julien Hany
			$json = array('url'=>'','count'=>0);
			$json['url'] = $_GET['url'];
			$url = urlencode($_GET['url']);
			$type = urlencode($_GET['type']);

			if(filter_var($_GET['url'], FILTER_VALIDATE_URL)){
			  if($type == 'googlePlus'){  //source http://www.helmutgranda.com/2011/11/01/get-a-url-google-count-via-php/
				$contents = plsh_parse('https://plusone.google.com/u/0/_/+1/fastbutton?url=' . $url . '&count=true');
				preg_match( '/window\.__SSR = {c: ([\d]+)/', $contents, $matches );

				if(isset($matches[0])){
				  $json['count'] = (int)str_replace('window.__SSR = {c: ', '', $matches[0]);
				}
			  }
			  else if($type == 'stumbleupon'){
				$content = plsh_parse("http://www.stumbleupon.com/services/1.01/badge.getinfo?url=$url");

				$result = json_decode($content);
				if (isset($result->result->views))
				{
					$json['count'] = $result->result->views;
				}

			  }
			}

			echo str_replace('\\/','/',json_encode($json));
			$data = ob_get_contents();
			ob_end_clean();
			die($data);
		}


		/*
		 * Init Mega Menu sidebar 
		 */
		function setup_constellation_sidebar($args) {

			$args['before_widget'] = '<div id="%1$s" class="constellation-widget section %2$s">';
			$args['after_widget'] = '</div>';
			$args['before_title'] = '<h3><span>';
			$args['after_title'] = '</span></h3>';

			return $args;
		}

		/*
		 * Custom excerpt lenght
		 */
		function custom_excerpt_length( $length ) 
		{
			return 50;
		}

		/*
		 * Custom excerpt more
		 */
		function custom_excerpt_more( $more )
		{
			return '...';
		}


		/*
		* Description: removes the silly 10px margin from the new caption based images
		* Author: Justin Adie
		* Version: 0.1.0
		* Author URI: http://rathercurious.net
		*/
		function fix_image_margins($x=null, $attr, $content)
		{
			extract(shortcode_atts(array(
				'id'    => '',
				'align'    => 'alignnone',
				'width'    => '',
				'caption' => ''
			), $attr));

			if ( 1 > (int) $width || empty($caption) )
			{
				return $content;
			}

			if ( $id )
			{
				$id = 'id="' . $id . '" ';
			}

			return '<div ' . $id . 'class="wp-caption ' . $align . '" style="width: ' . ((int) $width + 0) . 'px">'
			. $content . '<p class="wp-caption-text">' . $caption . '</p></div>';
		}


		/*
		 * Adjust the title tag output in homepage
		 */
		function wp_title_for_home( $title, $sep ) {
			if ( is_feed() ) 
			{
				return $title;
			}

			global $page, $paged;

			// Add the blog name
			$title .= get_bloginfo( 'name', 'display' );

			// Add the blog description for the home/front page.
			$site_description = get_bloginfo( 'description', 'display' );
			if ( $site_description && ( is_home() || is_front_page() ) ) 
			{
				$title .= " $sep $site_description";
			}

			// Add a page number if necessary:
			if ( ( $paged >= 2 || $page >= 2 ) && ! is_404() ) 
			{
				$title .= " $sep " . sprintf( __( 'Page %s', '_s' ), max( $paged, $page ) );
			}

			return $title;
		}

		/*
		 * Remove WooCommerce from theme settings
		 */
		function remove_woocommerce_settings()
		{
			global $_SETTINGS;
			if(!empty($_SETTINGS->admin_head['general']['children']['shop']))
			{
				unset($_SETTINGS->admin_head['general']['children']['shop']);
			}
			if(!empty($_SETTINGS->active['page_types']['shop']))
			{
				unset($_SETTINGS->active['page_types']['shop']);
			}
			if(!empty($_SETTINGS->active['page_types']['product']))
			{
				unset($_SETTINGS->active['page_types']['product']);
			}
		}

		/*
		 * Include scripts required by wordpress media upload used in widget fro special offers
		 */
		function widget_upload_enqueue()
		{
			wp_enqueue_media();
			wp_enqueue_script('plsh-widget-upload', PLSH_JS_URL. 'widget-upload.js', null, null, true);
		}

		/*
		 * Print footer scripts
		 */
		function print_scripts_in_footer( &$scripts) 
		{
			if ( ! is_admin() )
			{
				$scripts->add_data( 'comment-reply', 'group', 1 );
			}
		}

		/*
		 * Fix bug width wp_query parse
		 */
		function wpse_71157_parse_query( $wp_query )
		{
			if ( $wp_query->is_post_type_archive && $wp_query->is_tax )
			{
				$wp_query->is_post_type_archive = false;
			}
		}

		/*
		 * Force every widget to have non empty title
		 */
		function widget_title_force($title)
		{
			if(empty($title))
			{
				$title = ' ';
			}

			return $title;
		}
	}
}
	
/**
 * Force Visual Composer & Revslider to initialize as "built into the theme".
 */
if(function_exists('vc_set_as_theme')) { vc_set_as_theme(true); }

if(function_exists('set_revslider_as_theme')) { set_revslider_as_theme(); }

?>