<?php 
class PolarisContactsInfo extends WP_Widget {

    var $widget_cssclass;
	var $widget_description;
	var $widget_idbase;
	var $widget_name;
    
	function __construct() {

		/* Widget variable settings. */
		$this->widget_cssclass = 'contacts-info';
		$this->widget_description = __( 'Display your address and social network links', 'polaris' );
		$this->widget_idbase = 'polaris_contacts_info';
		$this->widget_name = __( 'Polaris Contacts & Info', 'polaris' );

		/* Widget settings. */
		$widget_ops = array( 'classname' => $this->widget_cssclass, 'description' => $this->widget_description );

		/* Create the widget. */
		parent::__construct('polaris_contacts_info', $this->widget_name, $widget_ops);

		add_action( 'save_post', array( $this, 'flush_widget_cache' ) );
		add_action( 'deleted_post', array( $this, 'flush_widget_cache' ) );
		add_action( 'switch_theme', array( $this, 'flush_widget_cache' ) );
	}

	function widget($args, $instance) 
    {
		$cache = wp_cache_get('polaris_contacts_info', 'widget');

		if ( !is_array($cache) )
			$cache = array();

		if ( ! isset( $args['widget_id'] ) )
			$args['widget_id'] = $this->id;

		if ( isset( $cache[ $args['widget_id'] ] ) ) {
			echo $cache[ $args['widget_id'] ];
			return;
		}

		ob_start();
		extract($args);
        global $post;

		$title = apply_filters('widget_title', empty($instance['title']) ? __('Recent Posts', 'polaris') : $instance['title'], $instance, $this->id_base);
        $address = isset( $instance['address'] ) ? $instance['address'] : '';
        $description = isset( $instance['description'] ) ? $instance['description'] : '';
        $show_social = isset( $instance['show_social'] ) ? $instance['show_social'] : false;

?>
       <?php echo $before_widget; ?>
       
		<?php echo $before_title . esc_html($title) . $after_title; ?>

        <div class="content">
            <div class="details">
                <?php echo wpautop($address); ?>
            </div>
            <div class="notes">
                <?php echo wpautop($description); ?>
            </div>
            <?php if($show_social) : ?>
            <div class="social">
                <?php get_template_part( 'theme/templates/social-icons'); ?>
            </div>
            <?php endif; ?>
        </div>

        <?php echo $after_widget; ?>
        <?php
		// Reset the global $the_post as this query will have stomped on it
		wp_reset_postdata();

		$cache[$args['widget_id']] = ob_get_flush();
		wp_cache_set('polaris_contacts_info', $cache, 'widget');
	}

	function update( $new_instance, $old_instance ) 
    {
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);        
        $instance['address'] = $new_instance['address'];
        $instance['description'] = $new_instance['description'];        
        $instance['show_social'] = $new_instance['show_social'];
               
		$this->flush_widget_cache();

		$alloptions = wp_cache_get( 'alloptions', 'options' );
		if ( isset($alloptions['polaris_contacts_info']) )
			delete_option('polaris_contacts_info');

		return $instance;
	}

	function flush_widget_cache() 
    {
		wp_cache_delete('polaris_contacts_info', 'widget');
	}

	function form( $instance ) 
    {           
        $title     = isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : '';
        $address   = isset( $instance['address'] ) ? $instance['address'] : ''; 
        $description   = isset( $instance['description'] ) ? $instance['description'] : ''; 
        $show_social = isset( $instance['show_social'] ) ? (bool) $instance['show_social'] : false;
        
        ?>
            <p>
                <label for="<?php echo esc_attr($this->get_field_id( 'title' )); ?>"><?php _e( 'Title:' , 'polaris'); ?></label>
                <input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'title' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'title' )); ?>" type="text" value="<?php echo esc_attr($title); ?>" />
            </p>    
        
            <p>
                <label for="<?php echo esc_attr($this->get_field_id( 'address' )); ?>"><?php _e( 'Address:' , 'polaris'); ?></label>
                <textarea class="widefat" name="<?php echo $this->get_field_name( 'address' ); ?>"><?php echo $address; ?></textarea>
            </p>
                        
            <p>
                <label for="<?php echo esc_attr($this->get_field_id( 'description' )); ?>"><?php _e( 'Description:' , 'polaris'); ?></label>
                <textarea class="widefat" name="<?php echo $this->get_field_name( 'description' ); ?>"><?php echo $description; ?></textarea>
            </p>            
            
            <p><input class="checkbox" type="checkbox" <?php checked( $show_social ); ?> id="<?php echo $this->get_field_id( 'show_social' ); ?>" name="<?php echo $this->get_field_name( 'show_social' ); ?>" />
    		<label for="<?php echo $this->get_field_id( 'show_social' ); ?>"><?php _e( 'Show social icons?', 'polaris' ); ?></label></p>
        <?php
	}
}