<?php 
class PolarisDropdownSpecialOffers extends WP_Widget {

    var $widget_cssclass;
	var $widget_description;
	var $widget_idbase;
	var $widget_name;
    
	function __construct() {

		/* Widget variable settings. */
		$this->widget_cssclass = 'dropdown-special-offers';
		$this->widget_description = __( 'Special shop offers element for mega menu', 'polaris' );
		$this->widget_idbase = 'polaris_dropdown_special_offers';
		$this->widget_name = __( 'Polaris Dropdown Special Offers', 'polaris' );

		/* Widget settings. */
		$widget_ops = array( 'classname' => $this->widget_cssclass, 'description' => $this->widget_description );

		/* Create the widget. */
		parent::__construct('polaris_dropdown_special_offers', $this->widget_name, $widget_ops);

		add_action( 'save_post', array( $this, 'flush_widget_cache' ) );
		add_action( 'deleted_post', array( $this, 'flush_widget_cache' ) );
		add_action( 'switch_theme', array( $this, 'flush_widget_cache' ) );
	}

	function widget($args, $instance) 
    {
		$cache = wp_cache_get('polaris_dropdown_special_offers', 'widget');

		if ( !is_array($cache) )
			$cache = array();

		if ( ! isset( $args['widget_id'] ) )
			$args['widget_id'] = $this->id;

		if ( isset( $cache[ $args['widget_id'] ] ) ) {
			echo $cache[ $args['widget_id'] ];
			return;
		}

		ob_start();
		extract($args);
        global $post;   
		?>
        <?php echo $before_widget; ?>
       
        <div class="offers-grid">

            <?php
            for($i = 1; $i<=3; $i++) { 
                $title = isset( $instance['title_' . $i] ) ? esc_attr( $instance['title_' . $i] ) : '';
                $description = isset( $instance['description_' . $i] ) ? esc_attr( $instance['description_' . $i] ) : '';
                $url = isset( $instance['url_' . $i] ) ? esc_attr( $instance['url_' . $i] ) : '';
                $btn_text = isset( $instance['btn_text_' . $i] ) ? esc_attr( $instance['btn_text_' . $i] ) : '';
                $image_uri = isset( $instance['image_uri_' . $i] ) ? esc_attr( $instance['image_uri_' . $i] ) : '';
                
                $image = plsh_get_attachment_src($image_uri);
                
                ?>
                <div class="offer" style="background-image: url(<?php echo esc_url($image); ?>);">
                    
                    <?php if(!empty($title) || !empty($description)) : ?>
                        <div class="title">
                            <h2><?php echo esc_html($title); ?></h2>
                            <p><?php echo esc_html($description); ?></p>
                        </div>
                    <?php endif; ?>
                    
                    <?php if(!empty($btn_text)) : ?>
                        <div class="start-shopping">
                            <a href="<?php echo esc_url($url); ?>" class="btn-medium-2"><?php echo esc_html($btn_text); ?></a>
                        </div>
                    <?php endif; ?>
                    
                </div>
            <?php } ?>
            
        </div>



        <?php echo $after_widget; ?>
        <?php
		// Reset the global $the_post as this query will have stomped on it
		wp_reset_postdata();

		$cache[$args['widget_id']] = ob_get_flush();
		wp_cache_set('polaris_dropdown_special_offers', $cache, 'widget');
	}

	function update( $new_instance, $old_instance ) 
    {
		$instance = $old_instance;
		
        for($i=1; $i<=3; $i++)
        {
            $instance['title_' . $i] = strip_tags($new_instance['title_' . $i]);
            $instance['description_' . $i] = strip_tags($new_instance['description_' . $i]);
            $instance['url_' . $i] = strip_tags($new_instance['url_' . $i]);
            $instance['btn_text_' . $i] = strip_tags($new_instance['btn_text_' . $i]);
            $instance['image_uri_' . $i] = strip_tags($new_instance['image_uri_' . $i]);
        }

		$this->flush_widget_cache();

		$alloptions = wp_cache_get( 'alloptions', 'options' );
		if ( isset($alloptions['polaris_dropdown_special_offers']) )
			delete_option('polaris_dropdown_special_offers');

		return $instance;
	}

	function flush_widget_cache() 
    {
		wp_cache_delete('polaris_dropdown_special_offers', 'widget');
	}

	function form( $instance ) 
    {
        for($i=1; $i<=3; $i++)
        {
            $items[$i]['title'] = isset( $instance['title_' . $i] ) ? esc_attr( $instance['title_' . $i] ) : '';
            $items[$i]['description'] = isset( $instance['description_' . $i] ) ? esc_attr( $instance['description_' . $i] ) : '';
            $items[$i]['url'] = isset( $instance['url_' . $i] ) ? esc_attr( $instance['url_' . $i] ) : '';
            $items[$i]['btn_text'] = isset( $instance['btn_text_' . $i] ) ? esc_attr( $instance['btn_text_' . $i] ) : '';
            $items[$i]['image_uri'] = isset( $instance['image_uri_' . $i] ) ? esc_attr( $instance['image_uri_' . $i] ) : '';
        }
        
        for($i=1; $i<=3; $i++)
        {
        ?>
            <h4><?php _e('Offer #' . $i, 'polaris'); ?></h4>
            <p>
                <label for="<?php echo esc_attr($this->get_field_id( 'title_' . $i )); ?>"><?php _e( 'Title:' , 'polaris'); ?></label>
                <input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'title_' . $i )); ?>" name="<?php echo esc_attr($this->get_field_name( 'title_' . $i )); ?>" type="text" value="<?php echo esc_attr($items[$i]['title']); ?>" />
            </p>
            <p>
                <label for="<?php echo esc_attr($this->get_field_id( 'description_' . $i )); ?>"><?php _e( 'Short description:' , 'polaris'); ?></label>
                <input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'description_' . $i )); ?>" name="<?php echo esc_attr($this->get_field_name( 'description_' . $i )); ?>" type="text" value="<?php echo esc_attr($items[$i]['description']); ?>" />
            </p>
            <p>
                <label for="<?php echo esc_attr($this->get_field_id( 'url_' . $i )); ?>"><?php _e( 'Button link:' , 'polaris'); ?></label>
                <input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'url_' . $i )); ?>" name="<?php echo esc_attr($this->get_field_name( 'url_' . $i )); ?>" type="text" value="<?php echo esc_attr($items[$i]['url']); ?>" />
            </p>
            <p>
                <label for="<?php echo esc_attr($this->get_field_id( 'btn_text_' . $i )); ?>"><?php _e( 'Button text:' , 'polaris'); ?></label>
                <input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'btn_text_' . $i )); ?>" name="<?php echo esc_attr($this->get_field_name( 'btn_text_' . $i )); ?>" type="text" value="<?php echo esc_attr($items[$i]['btn_text']); ?>" />
            </p>
            <p>
                <label for="<?php echo $this->get_field_id('image_uri_' . $i); ?>">Image</label><br />
                <input type="text" class="image-id" name="<?php echo $this->get_field_name('image_uri_' . $i); ?>" id="<?php echo $this->get_field_id('image_uri_' . $i); ?>" value="<?php echo esc_attr($items[$i]['image_uri']); ?>" />
                <input type="button" class="upload_image_button" id="<?php echo $this->get_field_id('img_btn_' . $i); ?>" value="Select Image" />
            </p>
            <br/>
        <?php
        }
	}
}