<?php 
class PolarisNewsletterMenu extends WP_Widget {

    var $widget_cssclass;
	var $widget_description;
	var $widget_idbase;
	var $widget_name;
    
	function __construct() {

		/* Widget variable settings. */
		$this->widget_cssclass = 'newsletter-menu';
		$this->widget_description = __( 'Display footer menu and newsletter signup form', 'polaris' );
		$this->widget_idbase = 'polaris_newsletter_menu';
		$this->widget_name = __( 'Polaris Footer Menu & Newsletter', 'polaris' );

		/* Widget settings. */
		$widget_ops = array( 'classname' => $this->widget_cssclass, 'description' => $this->widget_description );

		/* Create the widget. */
		parent::__construct('polaris_newsletter_menu', $this->widget_name, $widget_ops);

		add_action( 'save_post', array( $this, 'flush_widget_cache' ) );
		add_action( 'deleted_post', array( $this, 'flush_widget_cache' ) );
		add_action( 'switch_theme', array( $this, 'flush_widget_cache' ) );
	}

	function widget($args, $instance) 
    {
		$cache = wp_cache_get('polaris_newsletter_menu', 'widget');

		if ( !is_array($cache) )
			$cache = array();

		if ( ! isset( $args['widget_id'] ) )
			$args['widget_id'] = $this->id;

		if ( isset( $cache[ $args['widget_id'] ] ) ) {
			echo $cache[ $args['widget_id'] ];
			return;
		}

		ob_start();
		extract($args);
        global $post;

		$title = apply_filters('widget_title', empty($instance['title']) ? __('Recent Posts', 'polaris') : $instance['title'], $instance, $this->id_base);
        $menu = isset( $instance['menu'] ) ? $instance['menu'] : false;
        $description = isset( $instance['description'] ) ? $instance['description'] : '';
        $show_newsletter = isset( $instance['show_newsletter'] ) ? $instance['show_newsletter'] : false;

?>
       <?php echo $before_widget; ?>
       
		<?php echo $before_title . esc_html($title) . $after_title; ?>

        <div class="content">
            
            <?php
            if($menu)
            {
                $menu_items = wp_get_nav_menu_items($menu);
                
                if(!empty($menu_items))
                {
                    echo '<ul>';
                    foreach($menu_items as $mi)
                    {
                        echo '<li><a href="' . esc_url($mi->url) . '">' . $mi->title . '</a></li>';
                    }
                    echo '</ul>';
                }
            }
            ?>
            <div class="notes">
                <?php echo wpautop($description); ?>
            </div>
            
            <?php if($show_newsletter) : ?>
            <div class="search">
                <form action="<?php echo plsh_gs('newsletter_form_action'); ?>" class="contact-form" method="<?php echo plsh_gs('newsletter_form_method'); ?>">
                    <input type="text" name="<?php echo plsh_gs('newsletter_email_field'); ?>" placeholder="<?php _e('E-mail address', 'polaris'); ?>" class="input-submit"/><input type="submit" value="<?php _e('Subscribe', 'polaris'); ?>" class="btn-submit-1"/>
                </form>
            </div>
            <?php endif; ?>
            
        </div>

        <?php echo $after_widget; ?>
        <?php
		// Reset the global $the_post as this query will have stomped on it
		wp_reset_postdata();

		$cache[$args['widget_id']] = ob_get_flush();
		wp_cache_set('polaris_newsletter_menu', $cache, 'widget');
	}

	function update( $new_instance, $old_instance ) 
    {
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);        
        $instance['description'] = $new_instance['description'];        
        $instance['menu'] = $new_instance['menu'];
        $instance['show_newsletter'] = $new_instance['show_newsletter'];
               
		$this->flush_widget_cache();

		$alloptions = wp_cache_get( 'alloptions', 'options' );
		if ( isset($alloptions['polaris_newsletter_menu']) )
			delete_option('polaris_newsletter_menu');

		return $instance;
	}

	function flush_widget_cache() 
    {
		wp_cache_delete('polaris_newsletter_menu', 'widget');
	}

	function form( $instance ) 
    {           
        $title     = isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : '';
        $description   = isset( $instance['description'] ) ? $instance['description'] : ''; 
        $menu   = isset( $instance['menu'] ) ? $instance['menu'] : ''; 
        $show_newsletter = isset( $instance['show_newsletter'] ) ? (bool) $instance['show_newsletter'] : false;
        
        $menus_list = get_terms('nav_menu');
        $menus = array();
        foreach($menus_list as $ml)
        {
            $menus[$ml->term_id] = $ml->name;
        }
        
        ?>
            <p>
                <label for="<?php echo esc_attr($this->get_field_id( 'title' )); ?>"><?php _e( 'Title:' , 'polaris'); ?></label>
                <input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'title' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'title' )); ?>" type="text" value="<?php echo esc_attr($title); ?>" />
            </p>    
                
            <p>
                <label for="<?php echo esc_attr($this->get_field_id( 'menu' )); ?>"><?php _e( 'Menu:' , 'polaris'); ?></label>
                <select class="widefat" id="<?php echo esc_attr($this->get_field_id( 'menu' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'menu' )); ?>">
                    <?php
                    foreach($menus as $key => $menu_item)
                    {
                        $selected = ($menu == $key ? ' selected="selected"' : '');
                        echo '<option value="' . $key . '"' . $selected . '>' . $menu_item . '</option>';
                    }
                    ?>
                </select>
            </p>
            
            <p>
                <label for="<?php echo esc_attr($this->get_field_id( 'description' )); ?>"><?php _e( 'Description:' , 'polaris'); ?></label>
                <textarea class="widefat" name="<?php echo $this->get_field_name( 'description' ); ?>"><?php echo $description; ?></textarea>
            </p>            
            
            <p>
                <input class="checkbox" type="checkbox" <?php checked( $show_newsletter ); ?> id="<?php echo $this->get_field_id( 'show_newsletter' ); ?>" name="<?php echo $this->get_field_name( 'show_newsletter' ); ?>" />
                <label for="<?php echo $this->get_field_id( 'show_newsletter' ); ?>"><?php _e( 'Show newsletter form?', 'polaris' ); ?></label>
            </p>
        <?php
	}
}