<?php 
class PolarisProducts extends WP_Widget {

    var $widget_cssclass;
	var $widget_description;
	var $widget_idbase;
	var $widget_name;
    
	function __construct() {

		/* Widget variable settings. */
		$this->widget_cssclass = 'best-sellers';
		$this->widget_description = __( 'Display a collection of products', 'polaris' );
		$this->widget_idbase = 'polaris_products';
		$this->widget_name = __( 'Polaris Products', 'polaris' );

		/* Widget settings. */
		$widget_ops = array( 'classname' => $this->widget_cssclass, 'description' => $this->widget_description );

		/* Create the widget. */
		parent::__construct('polaris_products', $this->widget_name, $widget_ops);

		add_action( 'save_post', array( $this, 'flush_widget_cache' ) );
		add_action( 'deleted_post', array( $this, 'flush_widget_cache' ) );
		add_action( 'switch_theme', array( $this, 'flush_widget_cache' ) );
	}

	function widget($args, $instance) 
    {
		$cache = wp_cache_get('polaris_products', 'widget');

		if ( !is_array($cache) )
			$cache = array();

		if ( ! isset( $args['widget_id'] ) )
			$args['widget_id'] = $this->id;

		if ( isset( $cache[ $args['widget_id'] ] ) ) {
			echo $cache[ $args['widget_id'] ];
			return;
		}

		ob_start();
		extract($args);
        global $post;

		$title = apply_filters('widget_title', empty($instance['title']) ? __('Recent Products', 'polaris') : $instance['title'], $instance, $this->id_base);
        $count = isset( $instance['count'] ) ? $instance['count'] : 4;
        $type = isset( $instance['type'] ) ? $instance['type'] : 'recent_products';
 
        ?>
        <?php echo $before_widget; ?>
       
		<?php echo $before_title . esc_html($title) . $after_title; ?>

        <div class="best-sellers inline-2-grid">

            <?php echo do_shortcode('[' . $type . ' per_page="' . $count . '" columns="2"]'); ?>
            
        </div>
        
        <?php echo $after_widget; ?>
        <?php
		// Reset the global $the_post as this query will have stomped on it
		wp_reset_postdata();

		$cache[$args['widget_id']] = ob_get_flush();
		wp_cache_set('polaris_products', $cache, 'widget');
	}

	function update( $new_instance, $old_instance ) 
    {
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);        
        $instance['count'] = strip_tags($new_instance['count']);
        $instance['type'] = strip_tags($new_instance['type']);
               
		$this->flush_widget_cache();

		$alloptions = wp_cache_get( 'alloptions', 'options' );
		if ( isset($alloptions['polaris_products']) )
			delete_option('polaris_products');

		return $instance;
	}

	function flush_widget_cache() 
    {
		wp_cache_delete('polaris_products', 'widget');
	}

	function form( $instance ) 
    {           
        $title = isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : 'Products';
        $count = isset( $instance['count'] ) ? esc_attr( $instance['count'] ) : 4;
        $type  = isset( $instance['type'] ) ? esc_attr( $instance['type'] ) : 'recent_products';
        
        $types = array('recent_products', 'featured_products', 'sale_products', 'best_selling_products', 'top_rated_products');
        $type_names = array(
            'featured_products' => __('Featured Products', 'polaris'),
            'recent_products' => __('Recent Products', 'polaris'),
            'sale_products' =>  __('On Sale Products', 'polaris'),
            'best_selling_products' => __('Best Selling Products', 'polaris'),
            'top_rated_products' => __('Top Rated Products', 'polaris'),
        );
        
        ?>
            <p>
                <label for="<?php echo esc_attr($this->get_field_id( 'title' )); ?>"><?php _e( 'Title:' , 'polaris'); ?></label>
                <input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'title' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'title' )); ?>" type="text" value="<?php echo esc_attr($title); ?>" />
            </p>    
        
            <p>
                <label for="<?php echo esc_attr($this->get_field_id( 'count' )); ?>"><?php _e( 'Count:' , 'polaris'); ?></label>
                <input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'count' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'count' )); ?>" type="text" value="<?php echo esc_attr($count); ?>" />
            </p>
                        
            <p>
                <label for="<?php echo esc_attr($this->get_field_id( 'type' )); ?>"><?php _e( 'Type:', 'polaris' ); ?></label><br/>
                <select name="<?php echo esc_attr($this->get_field_name( 'type' )); ?>" id="<?php echo esc_attr($this->get_field_id( 'type' )); ?>" class="widefat">
                    <?php foreach($types as $type_item) : ?>
                        <option value="<?php echo esc_attr($type_item); ?>"<?php if($type == $type_item) echo ' selected="selected"'; ?>><?php echo esc_html($type_names[$type_item]); ?></option>
                    <?php endforeach; ?>'
                </select>
            </p>
        <?php
	}
}