<?php
if(!class_exists('PlanetshineWooCommerce'))
{
	class PlanetshineWooCommerce {

		function __construct() {
			
			/* Global - Change wrappers */
			remove_action( 'woocommerce_before_main_content', 'woocommerce_output_content_wrapper', 10);
			remove_action( 'woocommerce_after_main_content', 'woocommerce_output_content_wrapper_end', 10);
			add_action('woocommerce_before_main_content', array($this, 'theme_wrapper_start'), 10);
			add_action('woocommerce_after_main_content', array($this, 'theme_wrapper_end'), 10);
			
			/* Global - Unhook sidebar */
			remove_action( 'woocommerce_sidebar', 'woocommerce_get_sidebar', 10);
			
			/* Global - Filter Woo Price */
			//add_filter( 'woocommerce_get_price_html', array($this, 'get_price_html'), 100, 2 );
			
			/* Global - Set related product count */
			add_filter( 'woocommerce_output_related_products_args', array($this, 'related_products_args') );
			
			/* Global - add body tag classes for thank you and add quoute pages */
			add_filter( 'body_class', array($this, 'add_thank_you_class'));
			add_filter( 'body_class', array($this, 'add_quote_page_class'));
			
			/* Catalog - remove default breadcrumbs and page title */
			remove_action('woocommerce_before_main_content', 'woocommerce_breadcrumb', 20);
			add_filter('woocommerce_show_page_title', '__return_false');
			
			/* Catalog - Remove old category & shop descriptions and add new */
			remove_action( 'woocommerce_archive_description', 'woocommerce_taxonomy_archive_description', 10 );
			remove_action( 'woocommerce_archive_description', 'woocommerce_product_archive_description', 10 );
			add_action( 'woocommerce_archive_description', array($this, 'taxonomy_archive_description'), 10 );
			
			/* Catalog - Remove result count and default ordering */
			remove_action( 'woocommerce_before_shop_loop', 'woocommerce_result_count', 20 ); //remove result count
			remove_action( 'woocommerce_before_shop_loop', 'woocommerce_catalog_ordering', 30 ); //remove catalog ordering
			
			/* Catalog - Add product loop wrap and insert category filter */
			add_action('woocommerce_before_shop_loop', array($this, 'product_loop_wrap_start'), 100); //start product loop wrapper
			add_action('woocommerce_after_shop_loop', array($this, 'product_loop_wrap_end'), 100); //start product loop wrapper
			add_action('woocommerce_before_shop_loop', array($this, 'product_category_filter'), 40); //add catalog category filter
			
			/* Catalog replace default product loop thumbnail with custom one */
			remove_action( 'woocommerce_before_shop_loop_item_title', 'woocommerce_template_loop_product_thumbnail', 10 ); //remove product image
			add_action( 'woocommerce_before_shop_loop_item_title', array($this, 'template_loop_product_thumbnail'), 10 ); //remove product image
            	
			/* Catalog - remove rating & default sale flash */
			remove_action( 'woocommerce_after_shop_loop_item_title', 'woocommerce_template_loop_rating', 5 ); //remove rating in catalog
			remove_action( 'woocommerce_before_single_product_summary', 'woocommerce_show_product_sale_flash', 10 ); //remove sale flash
			
            remove_action( 'woocommerce_before_shop_loop_item', 'woocommerce_template_loop_product_link_open', 10 );
            remove_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_product_link_close', 5 );
            
			/* Single Product - Add title breadcrumbs */
			add_action( 'woocommerce_before_main_content', array($this, 'product_title_breadcrumbs'), 20);   //title breadcrumbs
			
			/* Single Product - Move price higher on the product page */
			remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_price', 10 );
			add_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_price', 7 );

			/* Single Product - Move ratings lowever on the product page */
			remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_rating', 10 );
			add_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_rating', 19 );
        
			/* Single Product - Add new field - short product notes */
			add_action( 'woocommerce_single_product_summary', array($this, 'product_short_notes'), 12 );
			
			/* Single Product - Product details wrapper */
			add_action( 'woocommerce_single_product_summary', array($this, 'product_start_details'), 18 );
			add_action( 'woocommerce_single_product_summary', array($this, 'product_end_details'), 100 );
			
			/* Single Product - Hook simple product add to cart button move to be executed when all is loaded */
			add_action( 'woocommerce_before_single_product', array($this, 'product_move_simple_add_to_cart'), 1);
            
            remove_action( 'woocommerce_review_before_comment_meta', 'woocommerce_review_display_rating', 10 );
			
			/* Single Product - Move the YITH - Request Qoute Button */
			if(class_exists('YITH_YWRAQ_Frontend'))
			{
				$instance = YITH_YWRAQ_Frontend::get_instance();
				remove_action( 'woocommerce_single_product_summary', array( $instance, 'add_button_single_page' ), 35 );
				add_action( 'plsh_add_quote_button', array( $instance, 'add_button_single_page' ));
			}
			
			/* Cart - move cross sells lower */
			remove_action( 'woocommerce_cart_collaterals', 'woocommerce_cross_sell_display' ); //move cross sells lower
			add_action( 'woocommerce_after_cart', 'woocommerce_cross_sell_display' );
			
			/* Cart - Ensure cart contents update when products are added to the cart via AJAX */
			add_filter( 'woocommerce_add_to_cart_fragments', array($this, 'header_add_to_cart_fragment'));

			/* Cart - Ajax cart summary callback */
			add_action( 'wp_ajax_get_cart', array($this, 'cart_summary') );
			add_action( 'wp_ajax_nopriv_get_cart', array($this, 'cart_summary') );

			/* Planetshine Collection Shortcode callback */
			add_action( 'wp_ajax_load_woo_shortcode', array($this, 'load_woo_shortcode') );
			add_action( 'wp_ajax_nopriv_load_woo_shortcode', array($this, 'load_woo_shortcode') );
			
			/* Quickview callback */
			add_action( 'wp_ajax_load_woo_quickview', array($this, 'load_woo_quickview') );
			add_action( 'wp_ajax_nopriv_load_woo_quickview', array($this, 'load_woo_quickview') );

		}
		
		/*
		 * Start custom wrapper for woocommerce
		 */
		function theme_wrapper_start() 
		{
			?><div class="container-woocommerce"><?php
		}

		/*
		 * End custom wrapper for woocommerce
		 */
		function theme_wrapper_end() 
		{
			?></div><?php
		}
		
		/**
		 * Show an archive description on taxonomy archives
		 */
		function taxonomy_archive_description() 
		{
			get_template_part( 'theme/templates/woo-category-title' );
		}
		
		/**
		 * Starp product loop wrapper
		 */
		function product_loop_wrap_start()
		{
			?>
			<div class="container products-grid inline-3-grid catalog">
				<div class="container sidebar-<?php echo plsh_get_sidebar_position(); ?>">

				<?php
				if(plsh_is_woocommerce_active())
				{
					the_widget('WC_Widget_Layered_Nav_Filters', array('title' => __('Active filters', 'polaris')), array(
						'before_widget' => '<div class="active-filters">',
						'after_widget'  => '</div>',
						'before_title'  => '<h3>',
						'after_title'   => '</h3>'
					));
				}
				?>

			<?php
		}

		/**
		 * End product loop wrapper
		 */
		function product_loop_wrap_end()
		{
            ?>
				</div>
				<?php get_sidebar('shop'); ?>
			</div>
			<?php
		}
		
		/**
		 * Include product category filter
		 */
		function product_category_filter() 
		{
			get_template_part( 'theme/templates/woo-catalog-filter' );
		}
		
		/*
		 * Load custom product thumbnail for catalog items
		 */
		function template_loop_product_thumbnail()
		{
			get_template_part( 'theme/templates/woo-catalog-product-image' );
		}
		
		/*
		 * Load Product title breadcrumbs
		 */
		function product_title_breadcrumbs() 
		{
			if(is_product())
			{
				get_template_part( 'theme/templates/woo-product-breadcrumbs' );
			}
		}
		
		/*
		 * Product Short Notes
		 */
		function product_short_notes()
		{
			$use_product_notes = get_post_meta( get_the_ID(), $key = 'use_product_notes', $single = true );
			$product_notes = get_post_meta( get_the_ID(), $key = 'product_notes', $single = true );

			if(!empty($use_product_notes))
			{
				if($use_product_notes == 'use_global')
				{
					echo '<div class="attributes">' . plsh_gs('global_product_notes') . '</div>';
				}
				else if($use_product_notes == 'custom' && !empty($product_notes))
				{
					echo '<div class="attributes">' . plsh_kses_widget_html_field($product_notes) . '</div>';
				}
			}
		}
		
		/*
		 * Start product details wraper
		 */
		function product_start_details()
		{
			?>
				<div class="details">
			<?php
		}
		

		/*
		 * End product details wraper
		 */
		function product_end_details()
		{
			?>
				</div>
			<?php
		}
		
		/*
		 * Filter Price
		 */
		function get_price_html($price, $product )
		{    
			$price = str_replace('<span class="amount">', '', $price);
			$price = str_replace('<span class="from">', '', $price);
			$price = str_replace('</span>', '', $price);
			$price = str_replace('From: ', '<em>from</em>', $price);
			$price = str_replace('<ins>', '', $price);
			$price = str_replace('</ins>', '', $price);
			$price = str_replace('<del>', '<s>', $price);
			$price = str_replace('</del>', '</s>', $price);

			if(strpos($price, '</s>') !== false)
			{
				$price_parts = explode('</s>', $price);
				$price = $price_parts[1] . $price_parts[0] . '</s>';
			}

			if(strpos($price, '<i class="saved">') !== false)
			{
				$first = substr($price, 0, strpos($price, '<i class="saved">'));
				$last = substr($price, strpos($price, '<i class="saved">'), ((strpos($price, '</i>') + 4) - strpos($price, '<i class="saved">')));
				$middle = substr($price, strpos($price, '</i>') + 4);
				$price = $first . $middle . $last;
			}

			if(strpos($price, '<em>from</em>') !== false)
			{
				$parts = explode('<em>from</em>', $price);
				$price = '<em>from</em>' . trim($parts[0]) . ' ' . trim($parts[1]);
			}

			return $price;
		}
		
		/*
		 * Set correct amount of related products
		 */
		function related_products_args( $args )
		{
			$args['posts_per_page'] = 4; // 4 related products
			$args['columns'] = 4; // arranged in 2 columns
			return $args;
		}
		
		/*
		 * Move the add to cart for simple product 
		 */
		function product_move_simple_add_to_cart() 
		{
			global $product;

			//simple products
			if($product->is_type('simple'))
			{
				//move add to cart to be right below price
				remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_add_to_cart', 30 );
				add_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_add_to_cart', 8 );

				add_action( 'woocommerce_single_product_summary', array($this, 'simple_product_availability'), 4 );
			}

		}
		
		/*
		 * Filter product availability output
		 */
		function simple_product_availability()
		{
			global $product;

			// Availability
			$availability      = $product->get_availability();
			$availability_html = empty( $availability['availability'] ) ? '' : '<p class="stock ' . esc_attr( $availability['class'] ) . '">' . esc_html( $availability['availability'] ) . '</p>';

			echo apply_filters( 'woocommerce_stock_html', $availability_html, $availability['availability'], $product );	
		}
		
		/*
		 * Ajax cart content update
		 */
		function header_add_to_cart_fragment( $fragments ) 
		{
			ob_start();
			?><i class="fa fa-shopping-cart"></i><?php echo WC()->cart->get_cart_total(); ?><?php

			$fragments['plsh-cart-contents'] = ob_get_clean();

			return $fragments;
		}
		
		/*
		 * Get AJAX cart summary
		 */
		function cart_summary()
		{
			global $woocommerce;
			ob_start();

			?><i class="fa fa-shopping-cart"></i><?php echo WC()->cart->get_cart_total(); ?><?php

			$data = ob_get_contents();
			ob_end_clean();
			die($data);
		}
		
		/*
		 * Add body class for thank you page
		 */
		function add_thank_you_class($classes) {

			if ( plsh_is_woocommerce_active() && is_order_received_page()) {

				$classes[] = 'woocommerce-checkout-thankyou';
			}
			return $classes;
		}
		
		/*
		 * Add body class for add to quote page
		 */
		function add_quote_page_class($classes) {

			if(class_exists('YITH_Request_Quote'))
			{
				$page = get_option( 'ywraq_page_id');
				if($page == get_the_ID())
				{
					$classes[] = 'yith-request-quote';
				}		
			}

			return $classes;
		}
		
		/*
		 * Callback for woo shortcode VC block
		 */
		function load_woo_shortcode()
		{
			global $post;
			ob_start();


			$columns = intval($_POST['columns']);
			$count = intval($_POST['count']);
			$type = $_POST['type'];

			if($type == 'special')
			{
				$supported = array(
					'featured_products',
					'recent_products',
					'sale_products',
					'best_selling_products',
					'top_rated_products'
				);
				$shortcode = $_POST['property'];

				if(!in_array($shortcode, $supported)) die('shortcode not supported');

				echo do_shortcode('[' . $shortcode . ' per_page="' . esc_attr($count) . '" columns="' . esc_attr($columns) . '"]');
			}
			elseif($type == 'category')
			{
				$category = $_POST['property'];
				echo do_shortcode('[product_category category="' . esc_attr($category) . '" per_page="' . esc_attr($count) . '" columns="' . esc_attr($columns) . '"]');
			}

			$html = ob_get_contents();
			ob_end_clean();

			die($html);
		}
		
		/*
		 * Callback for AJAX quickview
		 */
		function load_woo_quickview()
		{
			global $post;
			ob_start();

			get_template_part( 'theme/templates/woo-quickview');

			$html = ob_get_contents();
			ob_end_clean();

			die($html);
		}
		
		/*
		 * Load social share code
		 */
		public function product_share()
		{
			get_template_part( 'theme/templates/social-share' );
		}
		
		/*
		 * Conditional function to check of the add to cart button should be shown
		 */
		public function yith_show_add_to_cart()
		{
			//check if the plugin is active
			if(!is_plugin_active('yith-woocommerce-catalog-mode' . '/init.php')) { return true; }
			
			if(
				(
					get_option( 'ywctm_enable_plugin' ) == 'yes'
					&&
					!is_user_logged_in()
				)
				||
					get_option( 'ywctm_enable_plugin' ) == 'yes'
					&&
					(
						get_option( 'ywctm_admin_view' ) == 'yes'
						&&
						current_user_can( 'administrator' )
						&&
						is_user_logged_in()
					)
			)
			{
				return false;
			}
				
			return true;
		}
		
		/*
		 * Recursive Woo Product Category output
		 */
		public function output_woo_category_list($data)
		{
			global $wp_query;
			$category_slug = '';
			$cat_obj = $wp_query->get_queried_object();

			if(!empty($cat_obj) && !empty($cat_obj->slug))
			{
				$category_slug = $cat_obj->slug;
			}

			foreach($data as $item)
			{
				echo '<li><a href="' . esc_url(get_term_link( $item->slug, 'product_cat' )) . '"><span>' . $item->name .'</span></a>';
				if(!empty($item->children))
				{
					echo '<ul>';
					$this->output_woo_category_list($item->children);
					echo '</ul>';
				}
				echo '</li>';
			}
		}
		
		/*
		 * Get products by tax
		 */
		function get_woocommerce_products_by_taxonomy($category = NULL, $tag = NULL, $count = 8)
		{
			$params = array(
				'product_cat' => $category,
				'product_tag' => $tag
			);
			return plsh_get_post_collection($params, $count, 1, 'data', 'DESC', 'product');
		}
		
		/*
		 * Product Wishlist button
		 */
		function product_wishlist_button()
		{
			?>
				<div class="links">
					<?php if(shortcode_exists('yith_wcwl_add_to_wishlist')) : ?>
						<?php echo do_shortcode('[yith_wcwl_add_to_wishlist]'); ?>
					<?php endif; ?>    
				</div>
			<?php
		}
		
		/*
		 * Get product catalog label
		 */
		function product_get_label() 
		{
			$meta = get_post_meta(get_the_ID());
			if(
				!empty($meta['product_label_color'])
				&&
				$meta['product_label_color'][0] != 'no_label'
				&&
				!empty($meta['product_label_text'])
				&&
				strlen(trim($meta['product_label_text'][0])) > 0
			)
			{            
				$tag_style = 'tag-bottom';
				if(plsh_gs('large_sale_labels') != 'on')
				{
					$tag_style = '';
				}
				echo '<span class="tag-big tag-' . $meta['product_label_color'][0] . ' ' . $tag_style . '">' . $meta['product_label_text'][0] . '</span>';
			}
		}
		
		/*
		 * Get offer tag style for woo products
		 */
		public function get_offer_tag_style($echo = true) {

			$style = 'offer-tag-2';
			if(plsh_gs('large_sale_labels') == 'on')
			{
				$style = 'offer-tag';
			}

			if($echo)
			{
				echo $style;
			}
			else
			{
				return $style;
			}
		}
		
		/*
		 * Add hooks required by quickshop window
		 */
		public function add_quickshop_hooks() {
			
			/* Single Product - Add title breadcrumbs */
			add_action( 'woocommerce_before_main_content', array($this, 'product_title_breadcrumbs'), 20);   //title breadcrumbs
			
			/* Single Product - Move price higher on the product page */
			remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_price', 10 );
			add_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_price', 7 );

			/* Single Product - Move ratings lowever on the product page */
			remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_rating', 10 );
			add_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_rating', 19 );
        
			/* Single Product - Add new field - short product notes */
			add_action( 'woocommerce_single_product_summary', array($this, 'product_short_notes'), 12 );
			
			/* Single Product - Product details wrapper */
			add_action( 'woocommerce_single_product_summary', array($this, 'product_start_details'), 18 );
			add_action( 'woocommerce_single_product_summary', array($this, 'product_end_details'), 100 );
			
			/* Single Product - Hook simple product add to cart button move to be executed when all is loaded */
			add_action( 'woocommerce_before_single_product', array($this, 'product_move_simple_add_to_cart'), 1);
			
			/* Single Product - Move the YITH - Request Qoute Button */
			if(class_exists('YITH_YWRAQ_Frontend'))
			{
				$instance = YITH_YWRAQ_Frontend::get_instance();
				remove_action( 'woocommerce_single_product_summary', array( $instance, 'add_button_single_page' ), 35 );
				add_action( 'plsh_add_quote_button', array( $instance, 'add_button_single_page' ));
			}
			
		}
	}
}

//for global use - defaults
$polaris_woocommerce_loop = array('loop' => 0, 'columns' => 3);