<?php
/**
 * Display single product reviews (comments)
 *
 * @author 		WooThemes
 * @package 	WooCommerce/Templates
 * @version     3.2.0
 */
global $product;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

if ( ! comments_open() ) {
	return;
}

?>
<div id="reviews">
	<div id="comments">
		<?php if ( have_comments() ) : ?>

			<ul class="comments">
				<?php wp_list_comments( apply_filters( 'woocommerce_product_review_list_args', array( 'callback' => 'woocommerce_comments' ) ) ); ?>
			</ul>

			<?php if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) :
				echo '<nav class="woocommerce-pagination">';
				paginate_comments_links( apply_filters( 'woocommerce_comment_pagination_args', array(
					'prev_text' => '&larr;',
					'next_text' => '&rarr;',
					'type'      => 'list',
				) ) );
				echo '</nav>';
			endif; ?>

		<?php else : ?>

			<p class="woocommerce-noreviews"><?php _e( 'There are no reviews yet.', 'woocommerce' ); ?></p>

		<?php endif; ?>
	</div>

	<?php if ( get_option( 'woocommerce_review_rating_verification_required' ) === 'no' || wc_customer_bought_product( '', get_current_user_id(), $product->get_id() ) ) : ?>

		<div class="add-comment" id="review_form_wrapper">
			<div id="review_form">
                
                <div class="title"><span><?php echo have_comments() ? __( 'Add a review', 'polaris' ) : __( 'Be the first to review', 'polaris' ) . ' &ldquo;' . get_the_title() . '&rdquo;' ?></span></div>
                
				<?php
					
					$commenter = wp_get_current_commenter();
                    $logged_in = (get_current_user_id() > 0 ? 'user-logged-in' : '' );

					$comment_form = array(
						'title_reply'          => '',
						'title_reply_to'       => __( 'Leave a Reply to %s', 'woocommerce' ),
						'comment_notes_before' => '',
						'submit_button' => '<a href="#" id="comment-submit" class="btn-medium-1 ' . $logged_in . '"><i class="fa fa-comment"></i>' . __('Post your comment', 'polaris') . '</a>',
						'fields' => array(
							'a_start' => '<div class="data">',
							'author'  => '<input id="author" placeholder="' . __( 'Name', 'woocommerce' ) . '" name="author" type="text" value="' . esc_attr( $commenter['comment_author'] ) . '" size="30" aria-required="true" />',
							'email'   => '<input id="email" placeholder="' . __( 'Email', 'woocommerce' ) . '" name="email" type="text" value="' . esc_attr(  $commenter['comment_author_email'] ) . '" size="30" aria-required="true" />',
							'review'  => '<select name="rating" class="selectpicker show-tick" data-width="260px">
							<option value="">' . __( 'Rate&hellip;', 'woocommerce' ) . '</option>
							<option value="5">' . __( 'Perfect', 'woocommerce' ) . '</option>
							<option value="4">' . __( 'Good', 'woocommerce' ) . '</option>
							<option value="3">' . __( 'Average', 'woocommerce' ) . '</option>
							<option value="2">' . __( 'Not that bad', 'woocommerce' ) . '</option>
							<option value="1">' . __( 'Very Poor', 'woocommerce' ) . '</option>
							</select>',
							'z_end'	  => '</div>'
						),
						'label_submit'  => __( 'Submit', 'woocommerce' ),
						'logged_in_as'  => '',
						'comment_field' => '',
                        'id_submit' => 'hidden-submit',
					);
					
					
					if ( get_option( 'woocommerce_enable_review_rating' ) === 'yes' ) {
                        
                        if(get_current_user_id() > 0)
                        {
							$comment_form['comment_field'] = '<div class="data"><select name="rating" class="selectpicker show-tick" data-width="260px">
								<option value="">' . __( 'Rate&hellip;', 'woocommerce' ) . '</option>
								<option value="5">' . __( 'Perfect', 'woocommerce' ) . '</option>
								<option value="4">' . __( 'Good', 'woocommerce' ) . '</option>
								<option value="3">' . __( 'Average', 'woocommerce' ) . '</option>
								<option value="2">' . __( 'Not that bad', 'woocommerce' ) . '</option>
								<option value="1">' . __( 'Very Poor', 'woocommerce' ) . '</option>
							</select></div>';
						}
					}

					$comment_form['comment_field'] .= '<div class="comment"><textarea id="comment" placeholder="' . __( 'Your Review', 'polaris' ) . '" name="comment" class="form-control" aria-required="true"></textarea></div>';
					
					comment_form( apply_filters( 'woocommerce_product_review_comment_form_args', $comment_form ) );
				?>
			</div>
		</div>

	<?php else : ?>

		<p class="woocommerce-verification-required"><?php _e( 'Only logged in customers who have purchased this product may leave a review.', 'woocommerce' ); ?></p>

	<?php endif; ?>

	<div class="clear"></div>
</div>
