<?php
/**
 * Variable product add to cart
 *
 * @author  WooThemes
 * @package WooCommerce/Templates
 * @version 3.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

global $product, $post;

$attribute_keys = array_keys( $attributes );
?>
<?php do_action( 'woocommerce_before_add_to_cart_form' ); ?>

<form class="variations_form cart" method="post" enctype='multipart/form-data' data-product_id="<?php echo esc_attr($post->ID); ?>" data-product_variations="<?php echo htmlspecialchars( json_encode( $available_variations ) ) ?>">
	<?php if ( empty( $available_variations ) && false !== $available_variations ) : ?>
	
		<p class="stock out-of-stock"><?php _e( 'This product is currently out of stock and unavailable.', 'woocommerce' ); ?></p>
		
	<?php else : ?>
	
		<div class="variations">
            <?php $loop = 0; foreach ( $attributes as $attribute_name => $options ) : $loop++; ?>
                <div class="row">
                    <label for="<?php echo sanitize_title( $attribute_name ); ?>"><?php echo wc_attribute_label( $attribute_name ); ?></label>
					<select class="selectpicker show-tick" data-width="260px" id="<?php echo esc_attr( sanitize_title( $attribute_name ) ); ?>" name="attribute_<?php echo sanitize_title( $attribute_name ); ?>" data-attribute_name="attribute_<?php echo sanitize_title( $attribute_name ); ?>">
                        <option value=""><?php echo __( 'Choose an option', 'woocommerce' ) ?>&hellip;</option>
						
						<?php
							$selected = isset( $_REQUEST[ 'attribute_' . sanitize_title( $attribute_name ) ] ) ? wc_clean( stripslashes( urldecode( $_REQUEST[ 'attribute_' . sanitize_title( $attribute_name ) ] ) ) ) : $product->get_variation_default_attribute( $attribute_name );
							
							if ( empty( $options ) && ! empty( $product ) && ! empty( $attribute ) ) {
								$attributes = $product->get_variation_attributes();
								$options    = $attributes[ $attribute ];
							}
							$attribute = $attribute_name;
							
							if ( ! empty( $options ) ) {
								if ( $product && taxonomy_exists( $attribute ) ) {
									// Get terms if this is a taxonomy - ordered. We need the names too.
									$terms = wc_get_product_terms( $product->get_id(), $attribute, array( 'fields' => 'all' ) );

									foreach ( $terms as $term ) {
										if ( in_array( $term->slug, $options ) ) {
											echo '<option value="' . esc_attr( $term->slug ) . '" ' . selected( sanitize_title( $selected ), $term->slug, false ) . '>' . apply_filters( 'woocommerce_variation_option_name', $term->name ) . '</option>';
										}
									}
								} else {
									foreach ( $options as $option ) {
										// This handles < 2.4.0 bw compatibility where text attributes were not sanitized.
										$tmp_selected = sanitize_title( $selected ) === $selected ? selected( $selected, sanitize_title( $option ), false ) : selected( $selected, $option, false );
										echo '<option value="' . esc_attr( $option ) . '" ' . $tmp_selected . '>' . esc_html( apply_filters( 'woocommerce_variation_option_name', $option ) ) . '</option>';
									}
								}
							}
						?>
                    </select> <?php
					echo end( $attribute_keys ) === $attribute_name ? apply_filters( 'woocommerce_reset_variations_link', '<a class="reset_variations" href="#">' . __( 'Clear', 'woocommerce' ) . '</a>' ) : '';
                    ?>
                </div>
            <?php endforeach;?>
		</div>

		<?php do_action( 'woocommerce_before_add_to_cart_button' ); ?>

		<div class="single_variation_wrap" style="display:none;">
			<?php do_action( 'woocommerce_before_single_variation' ); ?>

			<div class="single_variation"></div>

			<div class="variations_button more">
				
				<?php
				global $_PLSH_WOO;
				
				if($_PLSH_WOO->yith_show_add_to_cart()) : ?>
				
					<?php woocommerce_quantity_input(); ?>

					<a href="#" class="btn-medium-1 single_add_to_cart_button"><i class="fa fa-shopping-cart"></i><?php echo esc_html($product->single_add_to_cart_text()); ?></a>

				<?php endif; ?>
					
                <?php global $_PLSH_WOO; $_PLSH_WOO->product_wishlist_button(); ?>
				
				<?php do_action( 'plsh_add_quote_button' ); ?>
			</div>

			<input type="hidden" name="add-to-cart" value="<?php echo esc_attr( $product->get_id()); ?>" />
			<input type="hidden" name="product_id" value="<?php echo esc_attr( $post->ID ); ?>" />
			<input type="hidden" name="variation_id" class="variation_id" value="" />

			<?php do_action( 'woocommerce_after_single_variation' ); ?>
		</div>

		<?php do_action( 'woocommerce_after_add_to_cart_button' ); ?>

	<?php endif; ?>

</form>

<?php do_action( 'woocommerce_after_add_to_cart_form' ); ?>
